# fmt: off
abstyles_license = "Abstyles License"
academic_free = "Academic Free License (AFL)"
academic_free_v1_1 = "Academic Free License v1.1"
academic_free_v1_2 = "Academic Free License v1.2"
academic_free_v2_0 = "Academic Free License v2.0"
academic_free_v2_1 = "Academic Free License v2.1"
academic_free_v3_0 = "Academic Free License v3.0"
academy_of_motion_picture_arts_and_sciences_bsd = "Academy of Motion Picture Arts and Sciences BSD"
adacore_doc_license = "AdaCore Doc License"
adaptive_public_license_1_0 = "Adaptive Public License 1.0"
adobe_display_postscript_license = "Adobe Display PostScript License"
adobe_glyph_list_license = "Adobe Glyph List License"
adobe_postscript_afm_license = "Adobe Postscript AFM License"
adobe_systems_incorporated_source_code_license_agreement = "Adobe Systems Incorporated Source Code License Agreement"
adobe_utopia_font_license = "Adobe Utopia Font License"
afmparse_license = "Afmparse License"
aladdin_free_public_license = "Aladdin Free Public License"
amazon_digital_services_license = "Amazon Digital Services License"
amd_newlib_license = "AMD newlib License"
amds_plpa_map_c_license = "AMD's plpa_map.c License"
aml_glslang_variant_license = "AML glslang variant License"
antlr_software_rights_notice = "ANTLR Software Rights Notice"
antlr_software_rights_notice_with_license_fallback = "ANTLR Software Rights Notice with license fallback"
any_osi_license = "Any OSI License"
any_osi_license___perl_modules = "Any OSI License - Perl Modules"
apache_license = "Apache license"
apache_license_1_1 = "Apache License 1.1"
apache_license_v1 = "Apache license 1.0"
apache_license_v2 = "Apache license 2.0"
app__s2p_license = "App::s2p License"
apple_mit_license = "Apple MIT License"
apple_public_source_license_1_0 = "Apple Public Source License 1.0"
apple_public_source_license_1_1 = "Apple Public Source License 1.1"
apple_public_source_license_1_2 = "Apple Public Source License 1.2"
apple_public_source_license_2_0 = "Apple Public Source License 2.0"
arphic_public_license = "Arphic Public License"
artistic_dist = "Artistic License 1.0 (dist)"
artistic_license = "Artistic License"
artistic_license_1_0 = "Artistic License 1.0"
artistic_license_1_0_perl = "Artistic License 1.0 (Perl)"
artistic_license_1_0_w_clause_8 = "Artistic License 1.0 w/clause 8"
artistic_license_2_0 = "Artistic License 2.0"
aspell_ru = "Aspell Russian License"
aswf_digital_assets_license_1_1 = "ASWF Digital Assets License 1.1"
aswf_digital_assets_license_version_1_0 = "ASWF Digital Assets License version 1.0"
attribution_assurance_license = "Attribution Assurance License"
azure_license = "Azure License"
baekmuk_license = "Baekmuk License"
bahyph_license = "Bahyph License"
barr_license = "Barr License"
bcrypt_solar_designer_license = "bcrypt Solar Designer License"
beerware_license = "Beerware License"
bitstream_charter_font_license = "Bitstream Charter Font License"
bitstream_vera_font_license = "Bitstream Vera Font License"
bittorrent_open_source_license_v1_0 = "BitTorrent Open Source License v1.0"
bittorrent_open_source_license_v1_1 = "BitTorrent Open Source License v1.1"
blue_oak_model_license_1_0_0 = "Blue Oak Model License 1.0.0"
boehm_demers_weiser_gc_license = "Boehm-Demers-Weiser GC License"
boehm_demers_weiser_gc_license_without_fee = "Boehm-Demers-Weiser GC License (without fee)"
boost_software_license_1_0 = "Boost Software License 1.0"
borceux_license = "Borceux license"
brian_gladman_2_clause_license = "Brian Gladman 2-Clause License"
brian_gladman_3_clause_license = "Brian Gladman 3-Clause License"
bsd_1_clause_license = "BSD 1-Clause License"
bsd_2_clause___first_lines_requirement = "BSD 2-Clause - first lines requirement"
bsd_2_clause___ian_darwin_variant = "BSD 2-Clause - Ian Darwin variant"
bsd_2_clause__freebsd = "BSD 2-Clause FreeBSD License"
bsd_2_clause__netbsd = "BSD 2-Clause NetBSD License"
bsd_2_clause_pkgconf_disclaimer = "BSD 2-Clause pkgconf disclaimer variant"
bsd_2_clause_plus_patent_license = "BSD-2-Clause Plus Patent License"
bsd_2_clause_simplified_license = "BSD 2-Clause \"Simplified\" License"
bsd_2_clause_with_views_sentence = "BSD 2-Clause with views sentence"
bsd_3_clause_acpica_variant = "BSD 3-Clause acpica variant"
bsd_3_clause_clear_license = "BSD 3-Clause Clear License"
bsd_3_clause_flex_variant = "BSD 3-Clause Flex variant"
bsd_3_clause_modification = "BSD 3-Clause Modification"
bsd_3_clause_new_or_revised_license = "BSD 3-Clause \"New\" or \"Revised\" License"
bsd_3_clause_no_military_license = "BSD 3-Clause No Military License"
bsd_3_clause_no_nuclear_license = "BSD 3-Clause No Nuclear License"
bsd_3_clause_no_nuclear_license_2014 = "BSD 3-Clause No Nuclear License 2014"
bsd_3_clause_no_nuclear_warranty = "BSD 3-Clause No Nuclear Warranty"
bsd_3_clause_open_mpi_variant = "BSD 3-Clause Open MPI variant"
bsd_3_clause_sun_microsystems = "BSD 3-Clause Sun Microsystems"
bsd_4_3_reno_license = "BSD 4.3 RENO License"
bsd_4_3_tahoe_license = "BSD 4.3 TAHOE License"
bsd_4_clause_original_or_old_license = "BSD 4-Clause \"Original\" or \"Old\" License"
bsd_4_clause_shortened = "BSD 4 Clause Shortened"
bsd_4_clause_university_of_california_specific = "BSD-4-Clause (University of California-Specific)"
bsd_advertising_acknowledgement_license = "BSD Advertising Acknowledgement License"
bsd_inferno_nettverk = "BSD-Inferno-Nettverk"
bsd_license = "BSD license"
bsd_license_c0 = "BSD 0-clause license"
bsd_license_c2 = "BSD 2-clause license"
bsd_license_c3 = "BSD 3-clause license"
bsd_license_c4 = "BSD 4-clause license"
bsd_protection_license = "BSD Protection License"
bsd_source_code_attribution = "BSD Source Code Attribution"
bsd_source_code_attribution___beginning_of_file_variant = "BSD Source Code Attribution - beginning of file variant"
bsd_with_attribution = "BSD with attribution"
bsd_with_attribution_and_hpnd_disclaimer = "BSD with Attribution and HPND disclaimer"
business_source_license_1_1 = "Business Source License 1.1"
bzip2_and_libbzip2_license_v1_0_5 = "bzip2 and libbzip2 License v1.0.5"
bzip2_and_libbzip2_license_v1_0_6 = "bzip2 and libbzip2 License v1.0.6"
caldera_license = "Caldera License"
caldera_license_without_preamble = "Caldera License (without preamble)"
catharon_license = "Catharon License"
cc0_license = "Creative Commons Zero, CC-0"
cecill_b_free_software_license_agreement = "CeCILL-B Free Software License Agreement"
cecill_c_free_software_license_agreement = "CeCILL-C Free Software License Agreement"
cecill_free_software_license_agreement_v1_0 = "CeCILL Free Software License Agreement v1.0"
cecill_free_software_license_agreement_v1_1 = "CeCILL Free Software License Agreement v1.1"
cecill_free_software_license_agreement_v2_0 = "CeCILL Free Software License Agreement v2.0"
cecill_free_software_license_agreement_v2_1 = "CeCILL Free Software License Agreement v2.1"
cern_open_hardware_licence_v1_1 = "CERN Open Hardware Licence v1.1"
cern_open_hardware_licence_v1_2 = "CERN Open Hardware Licence v1.2"
cern_open_hardware_licence_version_2___permissive = "CERN Open Hardware Licence Version 2 - Permissive"
cern_open_hardware_licence_version_2___strongly_reciprocal = "CERN Open Hardware Licence Version 2 - Strongly Reciprocal"
cern_open_hardware_licence_version_2___weakly_reciprocal = "CERN Open Hardware Licence Version 2 - Weakly Reciprocal"
cfitsio_license = "CFITSIO License"
check_cvs_license = "check-cvs License"
checkmk_license = "Checkmk License"
clarified_artistic_license = "Clarified Artistic License"
clips_license = "Clips License"
cmu_mach___no_notices_in_documentation_variant = "CMU Mach - no notices-in-documentation variant"
cmu_mach_license = "CMU Mach License"
cnri_jython_license = "CNRI Jython License"
cnri_python_license = "CNRI Python License"
cnri_python_open_source_gpl_compatible_license_agreement = "CNRI Python Open Source GPL Compatible License Agreement"
code_project_open_license_1_02 = "Code Project Open License 1.02"
common_development_and_distribution_license_1_0 = "Common Development and Distribution License 1.0"
common_development_and_distribution_license_1_1 = "Common Development and Distribution License 1.1"
common_documentation_license_1_0 = "Common Documentation License 1.0"
common_lisp_loop_license = "Common Lisp LOOP License"
common_public_attribution_license_1_0 = "Common Public Attribution License 1.0"
common_public_license_1_0 = "Common Public License 1.0"
common_vulnerability_enumeration_tou_license = "Common Vulnerability Enumeration ToU License"
community_data_license_agreement_permissive_1_0 = "Community Data License Agreement Permissive 1.0"
community_data_license_agreement_permissive_2_0 = "Community Data License Agreement Permissive 2.0"
community_data_license_agreement_sharing_1_0 = "Community Data License Agreement Sharing 1.0"
community_specification_license_1_0 = "Community Specification License 1.0"
computational_use_of_data_agreement_v1_0 = "Computational Use of Data Agreement v1.0"
computer_associates_trusted_open_source_license_1_1 = "Computer Associates Trusted Open Source License 1.1"
condor_public_license_v1_1 = "Condor Public License v1.1"
copyfree_open_innovation_license = "Copyfree Open Innovation License"
copyleft_next_0_3_0 = "copyleft-next 0.3.0"
copyleft_next_0_3_1 = "copyleft-next 0.3.1"
cornell_lossless_jpeg_license = "Cornell Lossless JPEG License"
creative_commons_attribution_1_0_generic = "Creative Commons Attribution 1.0 Generic"
creative_commons_attribution_2_0_generic = "Creative Commons Attribution 2.0 Generic"
creative_commons_attribution_2_5_australia = "Creative Commons Attribution 2.5 Australia"
creative_commons_attribution_2_5_generic = "Creative Commons Attribution 2.5 Generic"
creative_commons_attribution_3_0_australia = "Creative Commons Attribution 3.0 Australia"
creative_commons_attribution_3_0_austria = "Creative Commons Attribution 3.0 Austria"
creative_commons_attribution_3_0_germany = "Creative Commons Attribution 3.0 Germany"
creative_commons_attribution_3_0_igo = "Creative Commons Attribution 3.0 IGO"
creative_commons_attribution_3_0_netherlands = "Creative Commons Attribution 3.0 Netherlands"
creative_commons_attribution_3_0_united_states = "Creative Commons Attribution 3.0 United States"
creative_commons_attribution_3_0_unported = "Creative Commons Attribution 3.0 Unported"
creative_commons_attribution_4_0_international = "Creative Commons Attribution 4.0 International"
creative_commons_attribution_no_derivatives_1_0_generic = "Creative Commons Attribution No Derivatives 1.0 Generic"
creative_commons_attribution_no_derivatives_2_0_generic = "Creative Commons Attribution No Derivatives 2.0 Generic"
creative_commons_attribution_no_derivatives_2_5_generic = "Creative Commons Attribution No Derivatives 2.5 Generic"
creative_commons_attribution_no_derivatives_3_0_germany = "Creative Commons Attribution No Derivatives 3.0 Germany"
creative_commons_attribution_no_derivatives_3_0_unported = "Creative Commons Attribution No Derivatives 3.0 Unported"
creative_commons_attribution_no_derivatives_4_0_international = "Creative Commons Attribution No Derivatives 4.0 International"
creative_commons_attribution_non_commercial_1_0_generic = "Creative Commons Attribution Non Commercial 1.0 Generic"
creative_commons_attribution_non_commercial_2_0_generic = "Creative Commons Attribution Non Commercial 2.0 Generic"
creative_commons_attribution_non_commercial_2_5_generic = "Creative Commons Attribution Non Commercial 2.5 Generic"
creative_commons_attribution_non_commercial_3_0_germany = "Creative Commons Attribution Non Commercial 3.0 Germany"
creative_commons_attribution_non_commercial_3_0_unported = "Creative Commons Attribution Non Commercial 3.0 Unported"
creative_commons_attribution_non_commercial_4_0_international = "Creative Commons Attribution Non Commercial 4.0 International"
creative_commons_attribution_non_commercial_no_derivatives_1_0_generic = "Creative Commons Attribution Non Commercial No Derivatives 1.0 Generic"
creative_commons_attribution_non_commercial_no_derivatives_2_0_generic = "Creative Commons Attribution Non Commercial No Derivatives 2.0 Generic"
creative_commons_attribution_non_commercial_no_derivatives_2_5_generic = "Creative Commons Attribution Non Commercial No Derivatives 2.5 Generic"
creative_commons_attribution_non_commercial_no_derivatives_3_0_germany = "Creative Commons Attribution Non Commercial No Derivatives 3.0 Germany"
creative_commons_attribution_non_commercial_no_derivatives_3_0_igo = "Creative Commons Attribution Non Commercial No Derivatives 3.0 IGO"
creative_commons_attribution_non_commercial_no_derivatives_3_0_unported = "Creative Commons Attribution Non Commercial No Derivatives 3.0 Unported"
creative_commons_attribution_non_commercial_no_derivatives_4_0_international = "Creative Commons Attribution Non Commercial No Derivatives 4.0 International"
creative_commons_attribution_non_commercial_share_alike_1_0_generic = "Creative Commons Attribution Non Commercial Share Alike 1.0 Generic"
creative_commons_attribution_non_commercial_share_alike_2_0_england_and_wales = "Creative Commons Attribution Non Commercial Share Alike 2.0 England and Wales"
creative_commons_attribution_non_commercial_share_alike_2_0_generic = "Creative Commons Attribution Non Commercial Share Alike 2.0 Generic"
creative_commons_attribution_non_commercial_share_alike_2_0_germany = "Creative Commons Attribution Non Commercial Share Alike 2.0 Germany"
creative_commons_attribution_non_commercial_share_alike_2_5_generic = "Creative Commons Attribution Non Commercial Share Alike 2.5 Generic"
creative_commons_attribution_non_commercial_share_alike_3_0_germany = "Creative Commons Attribution Non Commercial Share Alike 3.0 Germany"
creative_commons_attribution_non_commercial_share_alike_3_0_igo = "Creative Commons Attribution Non Commercial Share Alike 3.0 IGO"
creative_commons_attribution_non_commercial_share_alike_3_0_unported = "Creative Commons Attribution Non Commercial Share Alike 3.0 Unported"
creative_commons_attribution_non_commercial_share_alike_4_0_international = "Creative Commons Attribution Non Commercial Share Alike 4.0 International"
creative_commons_attribution_noncommercial_sharealike_2_0_france = "Creative Commons Attribution-NonCommercial-ShareAlike 2.0 France"
creative_commons_attribution_share_alike_1_0_generic = "Creative Commons Attribution Share Alike 1.0 Generic"
creative_commons_attribution_share_alike_2_0_england_and_wales = "Creative Commons Attribution Share Alike 2.0 England and Wales"
creative_commons_attribution_share_alike_2_0_generic = "Creative Commons Attribution Share Alike 2.0 Generic"
creative_commons_attribution_share_alike_2_1_japan = "Creative Commons Attribution Share Alike 2.1 Japan"
creative_commons_attribution_share_alike_2_5_generic = "Creative Commons Attribution Share Alike 2.5 Generic"
creative_commons_attribution_share_alike_3_0_austria = "Creative Commons Attribution Share Alike 3.0 Austria"
creative_commons_attribution_share_alike_3_0_germany = "Creative Commons Attribution Share Alike 3.0 Germany"
creative_commons_attribution_share_alike_3_0_unported = "Creative Commons Attribution Share Alike 3.0 Unported"
creative_commons_attribution_share_alike_4_0_international = "Creative Commons Attribution Share Alike 4.0 International"
creative_commons_attribution_sharealike_3_0_igo = "Creative Commons Attribution-ShareAlike 3.0 IGO"
creative_commons_public_domain_dedication_and_certification = "Creative Commons Public Domain Dedication and Certification"
creative_commons_public_domain_mark_1_0_universal = "Creative Commons Public Domain Mark 1.0 Universal"
creative_commons_share_alike_1_0_generic = "Creative Commons Share Alike 1.0 Generic"
creative_commons_zero_v1_0_universal = "Creative Commons Zero v1.0 Universal"
cronyx_license = "Cronyx License"
crossword_license = "Crossword License"
cryptographic_autonomy_license_1_0 = "Cryptographic Autonomy License 1.0"
cryptographic_autonomy_license_1_0_combined_work_exception = "Cryptographic Autonomy License 1.0 (Combined Work Exception)"
cryptoswift = "CryptoSwift License"
crystalstacker_license = "CrystalStacker License"
cua_office_public_license_v1_0 = "CUA Office Public License v1.0"
cube_license = "Cube License"
curl_license = "curl License"
data_licence_germany__attribution__version_2_0 = "Data licence Germany attribution version 2.0"
data_licence_germany__zero__version_2_0 = "Data licence Germany zero version 2.0"
david_m__gay_dtoa_license = "David M. Gay dtoa License"
dec_3_clause_license = "DEC 3-Clause License"
detection_rule_license_1_0 = "Detection Rule License 1.0"
detection_rule_license_1_1 = "Detection Rule License 1.1"
deutsche_freie_software_lizenz = "Deutsche Freie Software Lizenz"
diffmark_license = "diffmark license"
doc_license = "DOC License"
docbook_dtd = "DocBook DTD License"
docbook_schema_license = "DocBook Schema License"
docbook_stylesheet_license = "DocBook Stylesheet License"
docbook_xml_license = "DocBook XML License"
dotseqn_license = "Dotseqn License"
dsdp_license = "DSDP License"
dvipdfm_license = "dvipdfm License"
eclipse_public_license_v1 = "Eclipse public license 1.0 (epl-1.0)"
eclipse_public_license_v2 = "Eclipse public license 2.0 (epl-2.0)"
ecos_license_v2_0 = "eCos license version 2.0"
educational_community_license_v1_0 = "Educational Community License v1.0"
educational_community_license_v2_0 = "Educational Community License v2.0"
egenix_com_public_license_1_1_0 = "eGenix.com Public License 1.1.0"
eiffel_forum_license_v1_0 = "Eiffel Forum License v1.0"
eiffel_forum_license_v2_0 = "Eiffel Forum License v2.0"
elastic_license_2_0 = "Elastic License 2.0"
enlightenment_license_e16 = "Enlightenment License (e16)"
enna_license = "enna License"
entessa_public_license_v1_0 = "Entessa Public License v1.0"
epics_open_license = "EPICS Open License"
erlang_public_license_v1_1 = "Erlang Public License v1.1"
etalab_open_license_2_0 = "Etalab Open License 2.0"
eu_datagrid_software_license = "EU DataGrid Software License"
european_union_public_license_1_0 = "European Union Public License 1.0"
european_union_public_license_1_1 = "European Union Public License 1.1"
european_union_public_license_1_2 = "European Union Public License 1.2"
eurosym_license = "Eurosym License"
fair_license = "Fair License"
feh_license = "feh License"
ferguson_twofish_license = "Ferguson Twofish License"
frameworx_open_license_1_0 = "Frameworx Open License 1.0"
fraunhofer_fdk_aac_codec_library = "Fraunhofer FDK AAC Codec Library"
freebsd_documentation_license = "FreeBSD Documentation License"
freeimage_public_license_v1_0 = "FreeImage Public License v1.0"
freetype_project_license = "Freetype Project License"
fsf_all_permissive_license = "FSF All Permissive License"
fsf_all_permissive_license_without_warranty = "FSF All Permissive License (without Warranty)"
fsf_unlimited_license = "FSF Unlimited License"
fsf_unlimited_license_with_license_retention = "FSF Unlimited License (with License Retention)"
fsf_unlimited_license_with_license_retention_and_warranty_disclaimer = "FSF Unlimited License (With License Retention and Warranty Disclaimer)"
fsfullrsd = "FSF Unlimited License (with License Retention and Short Disclaimer)"
fsl_1_1_alv2 = "Functional Source License, Version 1.1, ALv2 Future License"
fsl_1_1_mit = "Functional Source License, Version 1.1, MIT Future License"
furuseth_license = "Furuseth License"
fuzzy_bitmap_license = "Fuzzy Bitmap License"
fwlw_license = "fwlw License"
game_programming_gems = "Game Programming Gems License"
gd_license = "GD License"
generic_xts_license = "Generic XTS License"
giftware_license = "Giftware License"
gl2ps_license = "GL2PS License"
glulxe_license = "Glulxe License"
gnome_gcr_documentation_license = "Gnome GCR Documentation License"
gnu_affero = "GNU Affero general public license (apl)"
gnu_affero_general_public_license_v1_0_only = "GNU Affero General Public License v1.0 only"
gnu_affero_general_public_license_v1_0_or_later = "GNU Affero General Public License v1.0 or later"
gnu_affero_general_public_license_v2_0_only = "GNU Affero General Public License v2.0 only"
gnu_affero_general_public_license_v2_0_or_later = "GNU Affero General Public License v2.0 or later"
gnu_affero_general_public_license_v3_0_only = "GNU Affero General Public License v3.0 only"
gnu_affero_general_public_license_v3_0_or_later = "GNU Affero General Public License v3.0 or later"
gnu_free_documentation_license_v1_1_only = "GNU Free Documentation License v1.1 only"
gnu_free_documentation_license_v1_1_only___invariants = "GNU Free Documentation License v1.1 only - invariants"
gnu_free_documentation_license_v1_1_only___no_invariants = "GNU Free Documentation License v1.1 only - no invariants"
gnu_free_documentation_license_v1_1_or_later = "GNU Free Documentation License v1.1 or later"
gnu_free_documentation_license_v1_1_or_later___invariants = "GNU Free Documentation License v1.1 or later - invariants"
gnu_free_documentation_license_v1_1_or_later___no_invariants = "GNU Free Documentation License v1.1 or later - no invariants"
gnu_free_documentation_license_v1_2_only = "GNU Free Documentation License v1.2 only"
gnu_free_documentation_license_v1_2_only___invariants = "GNU Free Documentation License v1.2 only - invariants"
gnu_free_documentation_license_v1_2_only___no_invariants = "GNU Free Documentation License v1.2 only - no invariants"
gnu_free_documentation_license_v1_2_or_later = "GNU Free Documentation License v1.2 or later"
gnu_free_documentation_license_v1_2_or_later___invariants = "GNU Free Documentation License v1.2 or later - invariants"
gnu_free_documentation_license_v1_2_or_later___no_invariants = "GNU Free Documentation License v1.2 or later - no invariants"
gnu_free_documentation_license_v1_3_only = "GNU Free Documentation License v1.3 only"
gnu_free_documentation_license_v1_3_only___invariants = "GNU Free Documentation License v1.3 only - invariants"
gnu_free_documentation_license_v1_3_only___no_invariants = "GNU Free Documentation License v1.3 only - no invariants"
gnu_free_documentation_license_v1_3_or_later = "GNU Free Documentation License v1.3 or later"
gnu_free_documentation_license_v1_3_or_later___invariants = "GNU Free Documentation License v1.3 or later - invariants"
gnu_free_documentation_license_v1_3_or_later___no_invariants = "GNU Free Documentation License v1.3 or later - no invariants"
gnu_general_public_license_v1_0_only = "GNU General Public License v1.0 only"
gnu_general_public_license_v1_0_or_later = "GNU General Public License v1.0 or later"
gnu_general_public_license_v2_0_only = "GNU General Public License v2.0 only"
gnu_general_public_license_v2_0_or_later = "GNU General Public License v2.0 or later"
gnu_general_public_license_v2_0_w_autoconf_exception = "GNU General Public License v2.0 w/autoconf exception" 
gnu_general_public_license_v2_0_w_bison_exception = "GNU General Public License v2.0 w/bison exception" 
gnu_general_public_license_v2_0_w_classpath_exception = "GNU General Public License v2.0 w/classpath exception" 
gnu_general_public_license_v2_0_w_font_exception = "GNU General Public License v2.0 w/font exception" 
gnu_general_public_license_v2_0_w_gcc_runtime_library_exception = "GNU General Public License v2.0 w/gcc runtime library exception" 
gnu_general_public_license_v3_0_only = "GNU General Public License v3.0 only"
gnu_general_public_license_v3_0_or_later = "GNU General Public License v3.0 or later"
gnu_general_public_license_v3_0_w_autoconf_exception = "GNU General Public License v3.0 w/autoconf exception" 
gnu_general_public_license_v3_0_w_gcc_runtime_library_exception = "GNU General Public License v3.0 w/gcc runtime library exception" 
gnu_lesser_general_public_license = "GNU lesser general public license"
gnu_lesser_general_public_license_v2_0_only = "GNU Lesser General Public License v2.0 only"
gnu_lesser_general_public_license_v2_1_only = "GNU Lesser General Public License v2.1 only"
gnu_lesser_general_public_license_v2_1_or_later = "GNU Lesser General Public License v2.1 or later"
gnu_lesser_general_public_license_v3_0_only = "GNU Lesser General Public License v3.0 only"
gnu_lesser_general_public_license_v3_0_or_later = "GNU Lesser General Public License v3.0 or later"
gnu_library_general_public_license_v1_only = "GNU Library General Public License v1 only"
gnu_library_general_public_license_v1_or_later = "GNU Library General Public License v1 or later"
gnu_library_general_public_license_v2_only = "GNU Library General Public License v2 only"
gnu_library_general_public_license_v2_or_later = "GNU Library General Public License v2 or later"
gnu_public_license = "GNU general public license"
gnu_public_license_v2 = "GNU general public license v2 (gplv2)"
gnuplot_license = "gnuplot License"
good_luck_with_that_public_license = "Good Luck With That Public License"
graphics_gems_license = "Graphics Gems License"
gsoap_public_license_v1_3b = "gSOAP Public License v1.3b"
gtkbook_license = "gtkbook License"
gutmann_license = "Gutmann License"
haskell_language_report_license = "Haskell Language Report License"
hdf5 = "HDF5 License"
hdparm_license = "hdparm License"
hewlett_packard_1986_license = "Hewlett-Packard 1986 License"
hewlett_packard_1989_license = "Hewlett-Packard 1989 License"
hewlett_packard_bsd_variant_license = "Hewlett-Packard BSD variant license"
hidapi_license = "HIDAPI License"
hippocratic_license_2_1 = "Hippocratic License 2.1"
historical_permission_notice = "Historical Permission Notice and Disclaimer (HPND)"
historical_permission_notice_and_disclaimer___dec_variant = "Historical Permission Notice and Disclaimer - DEC variant"
historical_permission_notice_and_disclaimer___documentation_sell_variant = "Historical Permission Notice and Disclaimer - documentation sell variant"
historical_permission_notice_and_disclaimer___documentation_variant = "Historical Permission Notice and Disclaimer - documentation variant"
historical_permission_notice_and_disclaimer___fenneberg_livingston_variant = "Historical Permission Notice and Disclaimer - Fenneberg-Livingston variant"
historical_permission_notice_and_disclaimer___inria_imag_variant = "Historical Permission Notice and Disclaimer - INRIA-IMAG variant"
historical_permission_notice_and_disclaimer___intel_variant = "Historical Permission Notice and Disclaimer - Intel variant"
historical_permission_notice_and_disclaimer___kevlin_henney_variant = "Historical Permission Notice and Disclaimer - Kevlin Henney variant"
historical_permission_notice_and_disclaimer___markus_kuhn_variant = "Historical Permission Notice and Disclaimer - Markus Kuhn variant"
historical_permission_notice_and_disclaimer___merchantability_variant = "Historical Permission Notice and Disclaimer - merchantability variant"
historical_permission_notice_and_disclaimer___netrek_variant = "Historical Permission Notice and Disclaimer - Netrek variant"
historical_permission_notice_and_disclaimer___pbmplus_variant = "Historical Permission Notice and Disclaimer - Pbmplus variant"
historical_permission_notice_and_disclaimer___sell_regexpr_variant = "Historical Permission Notice and Disclaimer - sell regexpr variant"
historical_permission_notice_and_disclaimer___sell_variant = "Historical Permission Notice and Disclaimer - sell variant"
historical_permission_notice_and_disclaimer___sell_xserver_variant_with_mit_disclaimer = "Historical Permission Notice and Disclaimer - sell xserver variant with MIT disclaimer"
historical_permission_notice_and_disclaimer___university_of_california__us_export_warning = "Historical Permission Notice and Disclaimer - University of California, US export warning"
historical_permission_notice_and_disclaimer___university_of_california_variant = "Historical Permission Notice and Disclaimer - University of California variant"
historical_permission_notice_and_disclaimer_with_mit_disclaimer = "Historical Permission Notice and Disclaimer with MIT disclaimer"
hpnd_sell_variant_with_mit_disclaimer = "HPND sell variant with MIT disclaimer"
hpnd_sell_variant_with_mit_disclaimer___reverse = "HPND sell variant with MIT disclaimer - reverse"
hpnd_with_us_government_export_control_and_2_disclaimers = "HPND with US Government export control and 2 disclaimers"
hpnd_with_us_government_export_control_warning = "HPND with US Government export control warning"
hpnd_with_us_government_export_control_warning_and_acknowledgment = "HPND with US Government export control warning and acknowledgment"
hpnd_with_us_government_export_control_warning_and_modification_rqmt = "HPND with US Government export control warning and modification rqmt"
html_tidy_license = "HTML Tidy License"
ibm_powerpc_initialization_and_boot_software = "IBM PowerPC Initialization and Boot Software"
ibm_public_license_v1_0 = "IBM Public License v1.0"
icu_license = "ICU License"
iec_code_components_end_user_licence_agreement = "IEC Code Components End-user licence agreement"
imagemagick_license = "ImageMagick License"
imatix_standard_function_library_agreement = "iMatix Standard Function Library Agreement"
imlib2_license = "Imlib2 License"
independent_jpeg_group_license = "Independent JPEG Group License"
independent_jpeg_group_license___short = "Independent JPEG Group License - short"
info_zip_license = "Info-ZIP License"
inner_net_license_v2_0 = "Inner Net License v2.0"
inno_setup_license = "Inno Setup License"
intel_acpi_software_license_agreement = "Intel ACPI Software License Agreement"
intel_open_source_license = "Intel Open Source License"
interbase_public_license_v1_0 = "Interbase Public License v1.0"
ipa_font_license = "IPA Font License"
isc_license = "ISC license"
isc_veillard_variant = "ISC Veillard variant"
jam_license = "Jam License"
japan_network_information_center_license = "Japan Network Information Center License"
jasper_license = "JasPer License"
jove = "Jove License"
jpl_image_use_policy = "JPL Image Use Policy"
json_license = "JSON License"
kastrup_license = "Kastrup License"
kazlib_license = "Kazlib License"
knuth_ctan_license = "Knuth CTAN License"
latex_project_public_license_v1_0 = "LaTeX Project Public License v1.0"
latex_project_public_license_v1_1 = "LaTeX Project Public License v1.1"
latex_project_public_license_v1_2 = "LaTeX Project Public License v1.2"
latex_project_public_license_v1_3a = "LaTeX Project Public License v1.3a"
latex_project_public_license_v1_3c = "LaTeX Project Public License v1.3c"
latex2e_license = "Latex2e License"
latex2e_with_translated_notice_permission = "Latex2e with translated notice permission"
lawrence_berkeley_national_labs_bsd_variant_license = "Lawrence Berkeley National Labs BSD variant license"
leptonica_license = "Leptonica License"
lesser_general_public_license_for_linguistic_resources = "Lesser General Public License For Linguistic Resources"
libpng_1_6_35 = "PNG Reference Library License v1 (for libpng 0.5 through 1.6.35)"
libpng_license = "libpng License"
libselinux_public_domain_notice = "libselinux public domain notice"
libtiff_license = "libtiff License"
libutil_david_nugent_license = "libutil David Nugent License"
licence_art_libre_1_2 = "Licence Art Libre 1.2"
licence_art_libre_1_3 = "Licence Art Libre 1.3"
licence_libre_du_québec_permissive_version_1_1 = "Licence Libre du Québec Permissive version 1.1"
licence_libre_du_québec_Réciprocité_forte_version_1_1 = "Licence Libre du Québec Réciprocité forte version 1.1"
licence_libre_du_québec_Réciprocité_version_1_1 = "Licence Libre du Québec Réciprocité version 1.1"
linux_kernel_variant_of_openib_org_license = "Linux Kernel Variant of OpenIB.org license"
linux_man_pages___1_paragraph = "Linux man-pages - 1 paragraph"
linux_man_pages_copyleft = "Linux man-pages Copyleft"
linux_man_pages_copyleft___2_paragraphs = "Linux man-pages Copyleft - 2 paragraphs"
linux_man_pages_copyleft_variant = "Linux man-pages Copyleft Variant"
lpd_documentation_license = "LPD Documentation License"
lsof_license = "lsof License"
lucent_public_license_v1_02 = "Lucent Public License v1.02"
lucent_public_license_version_1_0 = "Lucent Public License Version 1.0"
lucida_bitmap_fonts_license = "Lucida Bitmap Fonts License"
lzma_sdk_license_versions_9_11_to_9_20 = "LZMA SDK License (versions 9.11 to 9.20)"
lzma_sdk_license_versions_9_22_and_beyond = "LZMA SDK License (versions 9.22 and beyond)"
mackerras_3_clause___acknowledgment_variant = "Mackerras 3-Clause - acknowledgment variant"
mackerras_3_clause_license = "Mackerras 3-Clause License"
magaz_license = "magaz License"
mailprio_license = "mailprio License"
makeindex_license = "MakeIndex License"
man2html = "man2html License"
martin_birgmeier_license = "Martin Birgmeier License"
matrix_template_library_license = "Matrix Template Library License"
mcphee_slideshow_license = "McPhee Slideshow License"
metamail_license = "metamail License"
michigan_merit_networks_license = "Michigan/Merit Networks License"
microsoft_limited_public_license = "Microsoft Limited Public License"
microsoft_public_license = "Microsoft Public License"
microsoft_reciprocal_license = "Microsoft Reciprocal License"
minpack_license = "Minpack License"
mips_license = "MIPS License"
mit_click_license = "MIT Click License"
mit_cmu = "CMU License (MIT-CMU)"
mit_festival_variant = "MIT Festival Variant"
mit_khronos___old_variant = "MIT Khronos - old variant"
mit_license = "MIT license"
mit_license_modern_variant = "MIT License Modern Variant"
mit_no_false_attribs_license = "MIT +no-false-attribs license"
mit_open_group_variant = "MIT Open Group variant"
mit_testregex_variant = "MIT testregex Variant"
mit_tom_wu_variant = "MIT Tom Wu Variant"
mit_zero_license = "MIT No Attribution"
mmixware_license = "MMIXware License"
motosoto_license = "Motosoto License"
mozilla_public_license_1_0 = "Mozilla Public License 1.0"
mozilla_public_license_1_1 = "Mozilla Public License 1.1"
mozilla_public_license_2_0_no_copyleft_exception = "Mozilla Public License 2.0 (no copyleft exception)"
mozilla_publice_license = "Mozilla public license (mpl)"
mozilla_publice_license_v2 = "Mozilla public license 2.0 (mpl 2.0)"
mpeg_software_simulation = "MPEG Software Simulation"
mpi_permissive_license = "mpi Permissive License"
mpich2_license = "mpich2 License"
mplus_font_license = "mplus Font License"
mulan_permissive_software_license__version_1 = "Mulan Permissive Software License, Version 1"
mulan_permissive_software_license__version_2 = "Mulan Permissive Software License, Version 2"
multics_license = "Multics License"
mup_license = "Mup License"
nara_institute_of_science_and_technology_license_2003 = "Nara Institute of Science and Technology License (2003)"
nasa_open_source_agreement_1_3 = "NASA Open Source Agreement 1.3"
naumen_public_license = "Naumen Public License"
ncbi_public_domain_notice = "NCBI Public Domain Notice"
ncl_source_code_license = "NCL Source Code License"
net_boolean_public_license_v1 = "Net Boolean Public License v1"
net_snmp_license = "Net-SNMP License"
netcdf_license = "NetCDF license"
nethack_general_public_license = "Nethack General Public License"
netizen_open_source_license = "Netizen Open Source License"
netscape_public_license_v1_0 = "Netscape Public License v1.0"
netscape_public_license_v1_1 = "Netscape Public License v1.1"
newsletr_license = "Newsletr License"
ngrep = "ngrep License"
nicta_public_software_license__version_1_0 = "NICTA Public Software License, Version 1.0"
nist_public_domain_notice = "NIST Public Domain Notice"
nist_public_domain_notice_with_license_fallback = "NIST Public Domain Notice with license fallback"
nist_software_license = "NIST Software License"
no_limit_public_license = "No Limit Public License"
nokia_open_source_license = "Nokia Open Source License"
non_commercial_government_licence = "Non-Commercial Government Licence"
non_profit_open_software_license_3_0 = "Non-Profit Open Software License 3.0"
norwegian_licence_for_open_government_data_nlod_1_0 = "Norwegian Licence for Open Government Data (NLOD) 1.0"
norwegian_licence_for_open_government_data_nlod_2_0 = "Norwegian Licence for Open Government Data (NLOD) 2.0"
noweb_license = "Noweb License"
nrl_license = "NRL License"
ntia_pd = "NTIA Public Domain Notice"
ntp_license = "NTP License"
ntp_no_attribution = "NTP No Attribution"
nunit_license = "Nunit License"
oar_license = "OAR License"
oclc_research_public_license_2_0 = "OCLC Research Public License 2.0"
offis_license = "OFFIS License"
ogc_software_license__version_1_0 = "OGC Software License, Version 1.0"
open_cascade_technology_public_license = "Open CASCADE Technology Public License"
open_data_commons_attribution_license_v1_0 = "Open Data Commons Attribution License v1.0"
open_data_commons_open_database_license_v1_0 = "Open Data Commons Open Database License v1.0"
open_data_commons_public_domain_dedication_and_license_1_0 = "Open Data Commons Public Domain Dedication & License 1.0"
open_government_licence___canada = "Open Government Licence - Canada"
open_government_licence_v1_0 = "Open Government Licence v1.0"
open_government_licence_v2_0 = "Open Government Licence v2.0"
open_government_licence_v3_0 = "Open Government Licence v3.0"
open_group_test_suite_license = "Open Group Test Suite License"
open_ldap_public_license_2_2_2 = "Open LDAP Public License 2.2.2"
open_ldap_public_license_v1_1 = "Open LDAP Public License v1.1"
open_ldap_public_license_v1_2 = "Open LDAP Public License v1.2"
open_ldap_public_license_v1_3 = "Open LDAP Public License v1.3"
open_ldap_public_license_v1_4 = "Open LDAP Public License v1.4"
open_ldap_public_license_v2_0_1 = "Open LDAP Public License v2.0.1"
open_ldap_public_license_v2_0_or_possibly_2_0a_and_2_0b = "Open LDAP Public License v2.0 (or possibly 2.0A and 2.0B)"
open_ldap_public_license_v2_1 = "Open LDAP Public License v2.1"
open_ldap_public_license_v2_2 = "Open LDAP Public License v2.2"
open_ldap_public_license_v2_2_1 = "Open LDAP Public License v2.2.1"
open_ldap_public_license_v2_3 = "Open LDAP Public License v2.3"
open_ldap_public_license_v2_4 = "Open LDAP Public License v2.4"
open_ldap_public_license_v2_5 = "Open LDAP Public License v2.5"
open_ldap_public_license_v2_6 = "Open LDAP Public License v2.6"
open_ldap_public_license_v2_7 = "Open LDAP Public License v2.7"
open_ldap_public_license_v2_8 = "Open LDAP Public License v2.8"
open_logistics_foundation_license_version_1_3 = "Open Logistics Foundation License Version 1.3"
open_market_license = "Open Market License"
open_public_license_v1_0 = "Open Public License v1.0"
open_publication_license_v1_0 = "Open Publication License v1.0"
open_software_license_1_0 = "Open Software License 1.0"
open_software_license_1_1 = "Open Software License 1.1"
open_software_license_2_0 = "Open Software License 2.0"
open_software_license_2_1 = "Open Software License 2.1"
open_software_license_3_0 = "Open Software License 3.0"
open_use_of_data_agreement_v1_0 = "Open Use of Data Agreement v1.0"
openpbs_v2_3_software_license = "OpenPBS v2.3 Software License"
openssl_license = "OpenSSL License"
openssl_license___standalone = "OpenSSL License - standalone"
openvision_license = "OpenVision License"
oset_public_license_version_2_1 = "OSET Public License version 2.1"
padl_license = "PADL License"
peer_production_license = "Peer Production License"
php_license_v3_0 = "PHP License v3.0"
php_license_v3_01 = "PHP License v3.01"
pixar_license = "Pixar License"
pkgconf_license = "pkgconf License"
plexus_classworlds_license = "Plexus Classworlds License"
png_reference_library_version_2 = "PNG Reference Library version 2"
pnmstitch_license = "pnmstitch License"
polyform_noncommercial_license_1_0_0 = "PolyForm Noncommercial License 1.0.0"
polyform_small_business_license_1_0_0 = "PolyForm Small Business License 1.0.0"
postgresql_license = "PostgreSQL License"
psfrag_license = "psfrag License"
psutils_license = "psutils License"
public_domain = "Public domain"
python_ldap_license = "Python ldap License"
python_license = "Python software foundation license"
python_license_2_0 = "Python License 2.0"
python_license_2_0_1 = "Python License 2.0.1"
python_license_v1 = "Python software foundation license v1"
python_license_v2 = "Python software foundation license v2"
q_public_license_1_0 = "Q Public License 1.0"
q_public_license_1_0___inria_2004_variant = "Q Public License 1.0 - INRIA 2004 variant"
qhull_license = "Qhull License"
radvd_license = "radvd License"
rdisc_license = "Rdisc License"
realnetworks_public_source_license_v1_0 = "RealNetworks Public Source License v1.0"
reciprocal_public_license_1_1 = "Reciprocal Public License 1.1"
reciprocal_public_license_1_5 = "Reciprocal Public License 1.5"
red_hat_ecos_public_license_v1_1 = "Red Hat eCos Public License v1.1"
repoze_license = "Repoze public license"
ricoh_source_code_public_license = "Ricoh Source Code Public License"
rsa_message_digest_license = "RSA Message-Digest License"
ruby_license = "Ruby License"
ruby_pty_extension_license = "Ruby pty extension license"
sax_public_domain_notice = "Sax Public Domain Notice"
sax_public_domain_notice_2_0 = "Sax Public Domain Notice 2.0"
saxpath_license = "Saxpath License"
scea_shared_source_license = "SCEA Shared Source License"
scheme_language_report_license = "Scheme Language Report License"
scheme_widget_library_swl_software_license_agreement = "Scheme Widget Library (SWL) Software License Agreement"
secure_messaging_protocol_public_license = "Secure Messaging Protocol Public License"
sendmail_license = "Sendmail License"
sendmail_license_8_23 = "Sendmail License 8.23"
sendmail_open_source_license_v1_1 = "Sendmail Open Source License v1.1"
server_side_public_license__v_1 = "Server Side Public License, v 1"
sgi_free_software_license_b_v1_0 = "SGI Free Software License B v1.0"
sgi_free_software_license_b_v1_1 = "SGI Free Software License B v1.1"
sgi_free_software_license_b_v2_0 = "SGI Free Software License B v2.0"
sgi_opengl_license = "SGI OpenGL License"
sgp4_permission_notice = "SGP4 Permission Notice"
sil_open_font_license_1_0 = "SIL Open Font License 1.0"
sil_open_font_license_1_0_with_no_reserved_font_name = "SIL Open Font License 1.0 with no Reserved Font Name"
sil_open_font_license_1_0_with_reserved_font_name = "SIL Open Font License 1.0 with Reserved Font Name"
sil_open_font_license_1_1 = "SIL Open Font License 1.1"
sil_open_font_license_1_1_with_no_reserved_font_name = "SIL Open Font License 1.1 with no Reserved Font Name"
sil_open_font_license_1_1_with_reserved_font_name = "SIL Open Font License 1.1 with Reserved Font Name"
simple_public_license_2_0 = "Simple Public License 2.0"
sl_license = "SL License"
sleepycat_license = "Sleepycat License"
smail_general_public_license = "SMAIL General Public License"
snia_public_license_1_1 = "SNIA Public License 1.1"
snprintf_license = "snprintf License"
sofa = "SOFA Software License"
softsurfer_license = "softSurfer License"
solderpad_hardware_license__version_0_51 = "Solderpad Hardware License, Version 0.51"
solderpad_hardware_license_v0_5 = "Solderpad Hardware License v0.5"
soundex_license = "Soundex License"
spdx_3d_slicer_license_v1_0 = "3D Slicer License v1.0"
spdx_3dfx_glide_license = "3dfx Glide License"
spencer_license_86 = "Spencer License 86"
spencer_license_94 = "Spencer License 94"
spencer_license_99 = "Spencer License 99"
sqlite_blessing = "SQLite Blessing"
ssh_keyscan_license = "ssh-keyscan License"
ssh_openssh_license = "SSH OpenSSH license"
ssh_short_notice = "SSH short notice"
ssleay_license___standalone = "SSLeay License - standalone"
standard_ml_of_new_jersey_license = "Standard ML of New Jersey License"
sugarcrm_public_license_v1_1_3 = "SugarCRM Public License v1.1.3"
sul_1_0 = "Sustainable Use License v1.0"
sun_industry_standards_source_license_v1_1 = "Sun Industry Standards Source License v1.1"
sun_industry_standards_source_license_v1_2 = "Sun Industry Standards Source License v1.2"
sun_ppp_license = "Sun PPP License"
sun_ppp_license_2000 = "Sun PPP License (2000)"
sun_public_license_v1_0 = "Sun Public License v1.0"
sunpro_license = "SunPro License"
swrule_license = "swrule License"
sybase_open_watcom_public_license_1_0 = "Sybase Open Watcom Public License 1.0"
symlinks_license = "Symlinks License"
systemics_bsd_variant_license = "Systemics BSD variant license"
systemics_w3works_bsd_variant_license = "Systemics W3Works BSD variant license"
taiwan_open_government_data_license__version_1_0 = "Taiwan Open Government Data License, version 1.0"
tapr_open_hardware_license_v1_0 = "TAPR Open Hardware License v1.0"
tcl_tk_license = "TCL/TK License"
tcp_wrappers_license = "TCP Wrappers License"
technische_universitaet_berlin_license_1_0 = "Technische Universitaet Berlin License 1.0"
technische_universitaet_berlin_license_2_0 = "Technische Universitaet Berlin License 2.0"
termreadkey_license = "TermReadKey License"
text_tabswrap_license = "Text-Tabs+Wrap License"
the_miros_licence = "The MirOS Licence"
the_parity_public_license_6_0_0 = "The Parity Public License 6.0.0"
the_parity_public_license_7_0_0 = "The Parity Public License 7.0.0"
thirdeye_license = "ThirdEye License"
thor_public_license_1_0 = "THOR Public License 1.0"
threeparttable_license = "threeparttable License"
time__parsedate_license = "Time::ParseDate License"
tmate_open_source_license = "TMate Open Source License"
torque_v2_5_software_license_v1_1 = "TORQUE v2.5+ Software License v1.1"
transitive_grace_period_public_licence_1_0 = "Transitive Grace Period Public Licence 1.0"
trusster_open_source_license = "Trusster Open Source License"
trustedqsl_license = "TrustedQSL License"
ttyp0_license = "TTYP0 License"
ubuntu_font_licence_v1_0 = "Ubuntu Font Licence v1.0"
ucar_license = "UCAR License"
ulem_license = "ulem License"
unicode_license_agreement___data_files_and_software_2015 = "Unicode License Agreement - Data Files and Software (2015)"
unicode_license_agreement___data_files_and_software_2016 = "Unicode License Agreement - Data Files and Software (2016)"
unicode_license_v3 = "Unicode License v3"
unicode_terms_of_use = "Unicode Terms of Use"
united_kingdom_open_parliament_licence_v3_0 = "United Kingdom Open Parliament Licence v3.0"
universal_permissive_license = "Universal Permissive License"
universal_permissive_license_v1_0 = "Universal Permissive License v1.0"
university_of_illinois_ncsa_open_source_license = "University of Illinois/NCSA Open Source License"
unixcrypt_license = "UnixCrypt License"
unlicense_libtelnet = "Unlicense - libtelnet variant"
unlicense_libwhirlpool = "Unlicense - libwhirlpool variant"
unlicensed_license = "The Unlicense (Unlicense)"
upstream_compatibility_license_v1_0 = "Upstream Compatibility License v1.0"
utah_raster_toolkit_run_length_encoded_license = "Utah Raster Toolkit Run Length Encoded License"
vim_license = "Vim License"
vostrom_public_license_for_open_source = "VOSTROM Public License for Open Source"
vovida_software_license_v1_0 = "Vovida Software License v1.0"
w3c_software_notice_and_document_license_2015_05_13 = "W3C Software Notice and Document License (2015-05-13)"
w3c_software_notice_and_license_1998_07_20 = "W3C Software Notice and License (1998-07-20)"
w3c_software_notice_and_license_2002_12_31 = "W3C Software Notice and License (2002-12-31)"
w3m_license = "w3m License"
widget_workshop_license = "Widget Workshop License"
wsuipa_license = "Wsuipa License"
wtf_you_want_license = "DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE"
wwl_license = "WWL License"
wxwindows = "wxWindows Library License"
x_net_license = "X.Net License"
x11_license = "X11 License"
x11_license_distribution_modification_variant = "X11 License Distribution Modification Variant"
x11_swapped_final_paragraphs = "X11 swapped final paragraphs"
xdebug_license_v_1_03 = "Xdebug License v 1.03"
xerox_license = "Xerox License"
xfig_license = "Xfig License"
xfree86_license_1_1 = "XFree86 License 1.1"
xinetd_license = "xinetd License"
xkeyboard_config_zinoviev_license = "xkeyboard-config Zinoviev License"
xlock_license = "xlock License"
xpp_license = "XPP License"
xskat_license = "XSkat License"
xzoom_license = "xzoom License"
yahoo_public_license_v1_0 = "Yahoo! Public License v1.0"
yahoo_public_license_v1_1 = "Yahoo! Public License v1.1"
zed_license = "Zed License"
zeeff_license = "Zeeff License"
zend_license_v2_0 = "Zend License v2.0"
zimbra_public_license_v1_3 = "Zimbra Public License v1.3"
zimbra_public_license_v1_4 = "Zimbra Public License v1.4"
zlib_libpng_license_with_acknowledgement = "zlib/libpng License with Acknowledgement"
zlib_license = "zlib License"
zope_public_license = "Zope Public License"
zope_public_license_1_1 = "Zope Public License 1.1"
zope_public_license_2_0 = "Zope Public License 2.0"
zope_public_license_2_1 = "Zope Public License 2.1"
zope_public_license_v1 = "Zope Public License v1"
zope_public_license_v2 = "Zope Public License v2"

# fmt: off

unknown_license = "There is no known license"

LICENSES_SYNONYMS = {
    abstyles_license.lower(): abstyles_license,
    academic_free_v1_1.lower(): academic_free_v1_1,
    academic_free_v1_2.lower(): academic_free_v1_2,
    academic_free_v2_0.lower(): academic_free_v2_0,
    academic_free_v2_1.lower(): academic_free_v2_1,
    academic_free_v3_0.lower(): academic_free_v3_0,
    academic_free.lower(): academic_free,
    academy_of_motion_picture_arts_and_sciences_bsd.lower(): academy_of_motion_picture_arts_and_sciences_bsd,
    adacore_doc_license.lower(): adacore_doc_license,
    adaptive_public_license_1_0.lower(): adaptive_public_license_1_0,
    adobe_display_postscript_license.lower(): adobe_display_postscript_license,
    adobe_glyph_list_license.lower(): adobe_glyph_list_license,
    adobe_postscript_afm_license.lower(): adobe_postscript_afm_license,
    adobe_systems_incorporated_source_code_license_agreement.lower(): adobe_systems_incorporated_source_code_license_agreement,
    adobe_utopia_font_license.lower(): adobe_utopia_font_license,
    afmparse_license.lower(): afmparse_license,
    aladdin_free_public_license.lower(): aladdin_free_public_license,
    amazon_digital_services_license.lower(): amazon_digital_services_license,
    amd_newlib_license.lower(): amd_newlib_license,
    amds_plpa_map_c_license.lower(): amds_plpa_map_c_license,
    aml_glslang_variant_license.lower(): aml_glslang_variant_license,
    antlr_software_rights_notice_with_license_fallback.lower(): antlr_software_rights_notice_with_license_fallback,
    antlr_software_rights_notice.lower(): antlr_software_rights_notice,
    any_osi_license___perl_modules.lower(): any_osi_license___perl_modules,
    any_osi_license.lower(): any_osi_license,
    apache_license_1_1.lower(): apache_license_1_1,
    apache_license_v1.lower(): apache_license_v1,
    apache_license_v2.lower(): apache_license_v2,
    apache_license.lower(): apache_license,
    app__s2p_license.lower(): app__s2p_license,
    apple_mit_license.lower(): apple_mit_license,
    apple_public_source_license_1_0.lower(): apple_public_source_license_1_0,
    apple_public_source_license_1_1.lower(): apple_public_source_license_1_1,
    apple_public_source_license_1_2.lower(): apple_public_source_license_1_2,
    apple_public_source_license_2_0.lower(): apple_public_source_license_2_0,
    arphic_public_license.lower(): arphic_public_license,
    artistic_dist.lower(): artistic_dist,
    artistic_license_1_0_perl.lower(): artistic_license_1_0_perl,
    artistic_license_1_0_w_clause_8.lower(): artistic_license_1_0_w_clause_8,
    artistic_license_1_0.lower(): artistic_license_1_0,
    artistic_license_2_0.lower(): artistic_license_2_0,
    artistic_license.lower(): artistic_license,
    aspell_ru.lower(): aspell_ru,
    aswf_digital_assets_license_1_1.lower(): aswf_digital_assets_license_1_1,
    aswf_digital_assets_license_version_1_0.lower(): aswf_digital_assets_license_version_1_0,
    attribution_assurance_license.lower(): attribution_assurance_license,
    azure_license.lower(): azure_license,
    baekmuk_license.lower(): baekmuk_license,
    bahyph_license.lower(): bahyph_license,
    barr_license.lower(): barr_license,
    bcrypt_solar_designer_license.lower(): bcrypt_solar_designer_license,
    beerware_license.lower(): beerware_license,
    bitstream_charter_font_license.lower(): bitstream_charter_font_license,
    bitstream_vera_font_license.lower(): bitstream_vera_font_license,
    bittorrent_open_source_license_v1_0.lower(): bittorrent_open_source_license_v1_0,
    bittorrent_open_source_license_v1_1.lower(): bittorrent_open_source_license_v1_1,
    blue_oak_model_license_1_0_0.lower(): blue_oak_model_license_1_0_0,
    boehm_demers_weiser_gc_license_without_fee.lower(): boehm_demers_weiser_gc_license_without_fee,
    boehm_demers_weiser_gc_license.lower(): boehm_demers_weiser_gc_license,
    boost_software_license_1_0.lower(): boost_software_license_1_0,
    borceux_license.lower(): borceux_license,
    brian_gladman_2_clause_license.lower(): brian_gladman_2_clause_license,
    brian_gladman_3_clause_license.lower(): brian_gladman_3_clause_license,
    bsd_1_clause_license.lower(): bsd_1_clause_license,
    bsd_2_clause___first_lines_requirement.lower(): bsd_2_clause___first_lines_requirement,
    bsd_2_clause___ian_darwin_variant.lower(): bsd_2_clause___ian_darwin_variant,
    bsd_2_clause__freebsd.lower(): bsd_2_clause__freebsd,
    bsd_2_clause__netbsd.lower(): bsd_2_clause__netbsd,
    bsd_2_clause_pkgconf_disclaimer.lower(): bsd_2_clause_pkgconf_disclaimer,
    bsd_2_clause_plus_patent_license.lower(): bsd_2_clause_plus_patent_license,
    bsd_2_clause_simplified_license.lower(): bsd_2_clause_simplified_license,
    bsd_2_clause_with_views_sentence.lower(): bsd_2_clause_with_views_sentence,
    bsd_3_clause_acpica_variant.lower(): bsd_3_clause_acpica_variant,
    bsd_3_clause_clear_license.lower(): bsd_3_clause_clear_license,
    bsd_3_clause_flex_variant.lower(): bsd_3_clause_flex_variant,
    bsd_3_clause_modification.lower(): bsd_3_clause_modification,
    bsd_3_clause_new_or_revised_license.lower(): bsd_3_clause_new_or_revised_license,
    bsd_3_clause_no_military_license.lower(): bsd_3_clause_no_military_license,
    bsd_3_clause_no_nuclear_license_2014.lower(): bsd_3_clause_no_nuclear_license_2014,
    bsd_3_clause_no_nuclear_license.lower(): bsd_3_clause_no_nuclear_license,
    bsd_3_clause_no_nuclear_warranty.lower(): bsd_3_clause_no_nuclear_warranty,
    bsd_3_clause_open_mpi_variant.lower(): bsd_3_clause_open_mpi_variant,
    bsd_3_clause_sun_microsystems.lower(): bsd_3_clause_sun_microsystems,
    bsd_4_3_reno_license.lower(): bsd_4_3_reno_license,
    bsd_4_3_tahoe_license.lower(): bsd_4_3_tahoe_license,
    bsd_4_clause_original_or_old_license.lower(): bsd_4_clause_original_or_old_license,
    bsd_4_clause_shortened.lower(): bsd_4_clause_shortened,
    bsd_4_clause_university_of_california_specific.lower(): bsd_4_clause_university_of_california_specific,
    bsd_advertising_acknowledgement_license.lower(): bsd_advertising_acknowledgement_license,
    bsd_inferno_nettverk.lower(): bsd_inferno_nettverk,
    bsd_license_c0.lower(): bsd_license_c0,
    bsd_license_c2.lower(): bsd_license_c2,
    bsd_license_c3.lower(): bsd_license_c3,
    bsd_license_c4.lower(): bsd_license_c4,
    bsd_license.lower(): bsd_license,
    bsd_protection_license.lower(): bsd_protection_license,
    bsd_source_code_attribution___beginning_of_file_variant.lower(): bsd_source_code_attribution___beginning_of_file_variant,
    bsd_source_code_attribution.lower(): bsd_source_code_attribution,
    bsd_with_attribution_and_hpnd_disclaimer.lower(): bsd_with_attribution_and_hpnd_disclaimer,
    bsd_with_attribution.lower(): bsd_with_attribution,
    business_source_license_1_1.lower(): business_source_license_1_1,
    bzip2_and_libbzip2_license_v1_0_5.lower(): bzip2_and_libbzip2_license_v1_0_5,
    bzip2_and_libbzip2_license_v1_0_6.lower(): bzip2_and_libbzip2_license_v1_0_6,
    caldera_license_without_preamble.lower(): caldera_license_without_preamble,
    caldera_license.lower(): caldera_license,
    catharon_license.lower(): catharon_license,
    cc0_license.lower(): cc0_license,
    cecill_b_free_software_license_agreement.lower(): cecill_b_free_software_license_agreement,
    cecill_c_free_software_license_agreement.lower(): cecill_c_free_software_license_agreement,
    cecill_free_software_license_agreement_v1_0.lower(): cecill_free_software_license_agreement_v1_0,
    cecill_free_software_license_agreement_v1_1.lower(): cecill_free_software_license_agreement_v1_1,
    cecill_free_software_license_agreement_v2_0.lower(): cecill_free_software_license_agreement_v2_0,
    cecill_free_software_license_agreement_v2_1.lower(): cecill_free_software_license_agreement_v2_1,
    cern_open_hardware_licence_v1_1.lower(): cern_open_hardware_licence_v1_1,
    cern_open_hardware_licence_v1_2.lower(): cern_open_hardware_licence_v1_2,
    cern_open_hardware_licence_version_2___permissive.lower(): cern_open_hardware_licence_version_2___permissive,
    cern_open_hardware_licence_version_2___strongly_reciprocal.lower(): cern_open_hardware_licence_version_2___strongly_reciprocal,
    cern_open_hardware_licence_version_2___weakly_reciprocal.lower(): cern_open_hardware_licence_version_2___weakly_reciprocal,
    cfitsio_license.lower(): cfitsio_license,
    check_cvs_license.lower(): check_cvs_license,
    checkmk_license.lower(): checkmk_license,
    clarified_artistic_license.lower(): clarified_artistic_license,
    clips_license.lower(): clips_license,
    cmu_mach___no_notices_in_documentation_variant.lower(): cmu_mach___no_notices_in_documentation_variant,
    cmu_mach_license.lower(): cmu_mach_license,
    cnri_jython_license.lower(): cnri_jython_license,
    cnri_python_license.lower(): cnri_python_license,
    cnri_python_open_source_gpl_compatible_license_agreement.lower(): cnri_python_open_source_gpl_compatible_license_agreement,
    code_project_open_license_1_02.lower(): code_project_open_license_1_02,
    common_development_and_distribution_license_1_0.lower(): common_development_and_distribution_license_1_0,
    common_development_and_distribution_license_1_1.lower(): common_development_and_distribution_license_1_1,
    common_documentation_license_1_0.lower(): common_documentation_license_1_0,
    common_lisp_loop_license.lower(): common_lisp_loop_license,
    common_public_attribution_license_1_0.lower(): common_public_attribution_license_1_0,
    common_public_license_1_0.lower(): common_public_license_1_0,
    common_vulnerability_enumeration_tou_license.lower(): common_vulnerability_enumeration_tou_license,
    community_data_license_agreement_permissive_1_0.lower(): community_data_license_agreement_permissive_1_0,
    community_data_license_agreement_permissive_2_0.lower(): community_data_license_agreement_permissive_2_0,
    community_data_license_agreement_sharing_1_0.lower(): community_data_license_agreement_sharing_1_0,
    community_specification_license_1_0.lower(): community_specification_license_1_0,
    computational_use_of_data_agreement_v1_0.lower(): computational_use_of_data_agreement_v1_0,
    computer_associates_trusted_open_source_license_1_1.lower(): computer_associates_trusted_open_source_license_1_1,
    condor_public_license_v1_1.lower(): condor_public_license_v1_1,
    copyfree_open_innovation_license.lower(): copyfree_open_innovation_license,
    copyleft_next_0_3_0.lower(): copyleft_next_0_3_0,
    copyleft_next_0_3_1.lower(): copyleft_next_0_3_1,
    cornell_lossless_jpeg_license.lower(): cornell_lossless_jpeg_license,
    creative_commons_attribution_1_0_generic.lower(): creative_commons_attribution_1_0_generic,
    creative_commons_attribution_2_0_generic.lower(): creative_commons_attribution_2_0_generic,
    creative_commons_attribution_2_5_australia.lower(): creative_commons_attribution_2_5_australia,
    creative_commons_attribution_2_5_generic.lower(): creative_commons_attribution_2_5_generic,
    creative_commons_attribution_3_0_australia.lower(): creative_commons_attribution_3_0_australia,
    creative_commons_attribution_3_0_austria.lower(): creative_commons_attribution_3_0_austria,
    creative_commons_attribution_3_0_germany.lower(): creative_commons_attribution_3_0_germany,
    creative_commons_attribution_3_0_igo.lower(): creative_commons_attribution_3_0_igo,
    creative_commons_attribution_3_0_netherlands.lower(): creative_commons_attribution_3_0_netherlands,
    creative_commons_attribution_3_0_united_states.lower(): creative_commons_attribution_3_0_united_states,
    creative_commons_attribution_3_0_unported.lower(): creative_commons_attribution_3_0_unported,
    creative_commons_attribution_4_0_international.lower(): creative_commons_attribution_4_0_international,
    creative_commons_attribution_no_derivatives_1_0_generic.lower(): creative_commons_attribution_no_derivatives_1_0_generic,
    creative_commons_attribution_no_derivatives_2_0_generic.lower(): creative_commons_attribution_no_derivatives_2_0_generic,
    creative_commons_attribution_no_derivatives_2_5_generic.lower(): creative_commons_attribution_no_derivatives_2_5_generic,
    creative_commons_attribution_no_derivatives_3_0_germany.lower(): creative_commons_attribution_no_derivatives_3_0_germany,
    creative_commons_attribution_no_derivatives_3_0_unported.lower(): creative_commons_attribution_no_derivatives_3_0_unported,
    creative_commons_attribution_no_derivatives_4_0_international.lower(): creative_commons_attribution_no_derivatives_4_0_international,
    creative_commons_attribution_non_commercial_1_0_generic.lower(): creative_commons_attribution_non_commercial_1_0_generic,
    creative_commons_attribution_non_commercial_2_0_generic.lower(): creative_commons_attribution_non_commercial_2_0_generic,
    creative_commons_attribution_non_commercial_2_5_generic.lower(): creative_commons_attribution_non_commercial_2_5_generic,
    creative_commons_attribution_non_commercial_3_0_germany.lower(): creative_commons_attribution_non_commercial_3_0_germany,
    creative_commons_attribution_non_commercial_3_0_unported.lower(): creative_commons_attribution_non_commercial_3_0_unported,
    creative_commons_attribution_non_commercial_4_0_international.lower(): creative_commons_attribution_non_commercial_4_0_international,
    creative_commons_attribution_non_commercial_no_derivatives_1_0_generic.lower(): creative_commons_attribution_non_commercial_no_derivatives_1_0_generic,
    creative_commons_attribution_non_commercial_no_derivatives_2_0_generic.lower(): creative_commons_attribution_non_commercial_no_derivatives_2_0_generic,
    creative_commons_attribution_non_commercial_no_derivatives_2_5_generic.lower(): creative_commons_attribution_non_commercial_no_derivatives_2_5_generic,
    creative_commons_attribution_non_commercial_no_derivatives_3_0_germany.lower(): creative_commons_attribution_non_commercial_no_derivatives_3_0_germany,
    creative_commons_attribution_non_commercial_no_derivatives_3_0_igo.lower(): creative_commons_attribution_non_commercial_no_derivatives_3_0_igo,
    creative_commons_attribution_non_commercial_no_derivatives_3_0_unported.lower(): creative_commons_attribution_non_commercial_no_derivatives_3_0_unported,
    creative_commons_attribution_non_commercial_no_derivatives_4_0_international.lower(): creative_commons_attribution_non_commercial_no_derivatives_4_0_international,
    creative_commons_attribution_non_commercial_share_alike_1_0_generic.lower(): creative_commons_attribution_non_commercial_share_alike_1_0_generic,
    creative_commons_attribution_non_commercial_share_alike_2_0_england_and_wales.lower(): creative_commons_attribution_non_commercial_share_alike_2_0_england_and_wales,
    creative_commons_attribution_non_commercial_share_alike_2_0_generic.lower(): creative_commons_attribution_non_commercial_share_alike_2_0_generic,
    creative_commons_attribution_non_commercial_share_alike_2_0_germany.lower(): creative_commons_attribution_non_commercial_share_alike_2_0_germany,
    creative_commons_attribution_non_commercial_share_alike_2_5_generic.lower(): creative_commons_attribution_non_commercial_share_alike_2_5_generic,
    creative_commons_attribution_non_commercial_share_alike_3_0_germany.lower(): creative_commons_attribution_non_commercial_share_alike_3_0_germany,
    creative_commons_attribution_non_commercial_share_alike_3_0_igo.lower(): creative_commons_attribution_non_commercial_share_alike_3_0_igo,
    creative_commons_attribution_non_commercial_share_alike_3_0_unported.lower(): creative_commons_attribution_non_commercial_share_alike_3_0_unported,
    creative_commons_attribution_non_commercial_share_alike_4_0_international.lower(): creative_commons_attribution_non_commercial_share_alike_4_0_international,
    creative_commons_attribution_noncommercial_sharealike_2_0_france.lower(): creative_commons_attribution_noncommercial_sharealike_2_0_france,
    creative_commons_attribution_share_alike_1_0_generic.lower(): creative_commons_attribution_share_alike_1_0_generic,
    creative_commons_attribution_share_alike_2_0_england_and_wales.lower(): creative_commons_attribution_share_alike_2_0_england_and_wales,
    creative_commons_attribution_share_alike_2_0_generic.lower(): creative_commons_attribution_share_alike_2_0_generic,
    creative_commons_attribution_share_alike_2_1_japan.lower(): creative_commons_attribution_share_alike_2_1_japan,
    creative_commons_attribution_share_alike_2_5_generic.lower(): creative_commons_attribution_share_alike_2_5_generic,
    creative_commons_attribution_share_alike_3_0_austria.lower(): creative_commons_attribution_share_alike_3_0_austria,
    creative_commons_attribution_share_alike_3_0_germany.lower(): creative_commons_attribution_share_alike_3_0_germany,
    creative_commons_attribution_share_alike_3_0_unported.lower(): creative_commons_attribution_share_alike_3_0_unported,
    creative_commons_attribution_share_alike_4_0_international.lower(): creative_commons_attribution_share_alike_4_0_international,
    creative_commons_attribution_sharealike_3_0_igo.lower(): creative_commons_attribution_sharealike_3_0_igo,
    creative_commons_public_domain_dedication_and_certification.lower(): creative_commons_public_domain_dedication_and_certification,
    creative_commons_public_domain_mark_1_0_universal.lower(): creative_commons_public_domain_mark_1_0_universal,
    creative_commons_share_alike_1_0_generic.lower(): creative_commons_share_alike_1_0_generic,
    creative_commons_zero_v1_0_universal.lower(): creative_commons_zero_v1_0_universal,
    cronyx_license.lower(): cronyx_license,
    crossword_license.lower(): crossword_license,
    cryptographic_autonomy_license_1_0_combined_work_exception.lower(): cryptographic_autonomy_license_1_0_combined_work_exception,
    cryptographic_autonomy_license_1_0.lower(): cryptographic_autonomy_license_1_0,
    cryptoswift.lower(): cryptoswift,
    crystalstacker_license.lower(): crystalstacker_license,
    cua_office_public_license_v1_0.lower(): cua_office_public_license_v1_0,
    cube_license.lower(): cube_license,
    curl_license.lower(): curl_license,
    data_licence_germany__attribution__version_2_0.lower(): data_licence_germany__attribution__version_2_0,
    data_licence_germany__zero__version_2_0.lower(): data_licence_germany__zero__version_2_0,
    david_m__gay_dtoa_license.lower(): david_m__gay_dtoa_license,
    dec_3_clause_license.lower(): dec_3_clause_license,
    detection_rule_license_1_0.lower(): detection_rule_license_1_0,
    detection_rule_license_1_1.lower(): detection_rule_license_1_1,
    deutsche_freie_software_lizenz.lower(): deutsche_freie_software_lizenz,
    diffmark_license.lower(): diffmark_license,
    doc_license.lower(): doc_license,
    docbook_dtd.lower(): docbook_dtd,
    docbook_schema_license.lower(): docbook_schema_license,
    docbook_stylesheet_license.lower(): docbook_stylesheet_license,
    docbook_xml_license.lower(): docbook_xml_license,
    dotseqn_license.lower(): dotseqn_license,
    dsdp_license.lower(): dsdp_license,
    dvipdfm_license.lower(): dvipdfm_license,
    eclipse_public_license_v1.lower(): eclipse_public_license_v1,
    eclipse_public_license_v2.lower(): eclipse_public_license_v2,
    ecos_license_v2_0.lower(): ecos_license_v2_0,
    educational_community_license_v1_0.lower(): educational_community_license_v1_0,
    educational_community_license_v2_0.lower(): educational_community_license_v2_0,
    egenix_com_public_license_1_1_0.lower(): egenix_com_public_license_1_1_0,
    eiffel_forum_license_v1_0.lower(): eiffel_forum_license_v1_0,
    eiffel_forum_license_v2_0.lower(): eiffel_forum_license_v2_0,
    elastic_license_2_0.lower(): elastic_license_2_0,
    enlightenment_license_e16.lower(): enlightenment_license_e16,
    enna_license.lower(): enna_license,
    entessa_public_license_v1_0.lower(): entessa_public_license_v1_0,
    epics_open_license.lower(): epics_open_license,
    erlang_public_license_v1_1.lower(): erlang_public_license_v1_1,
    etalab_open_license_2_0.lower(): etalab_open_license_2_0,
    eu_datagrid_software_license.lower(): eu_datagrid_software_license,
    european_union_public_license_1_0.lower(): european_union_public_license_1_0,
    european_union_public_license_1_1.lower(): european_union_public_license_1_1,
    european_union_public_license_1_2.lower(): european_union_public_license_1_2,
    eurosym_license.lower(): eurosym_license,
    fair_license.lower(): fair_license,
    feh_license.lower(): feh_license,
    ferguson_twofish_license.lower(): ferguson_twofish_license,
    frameworx_open_license_1_0.lower(): frameworx_open_license_1_0,
    fraunhofer_fdk_aac_codec_library.lower(): fraunhofer_fdk_aac_codec_library,
    freebsd_documentation_license.lower(): freebsd_documentation_license,
    freeimage_public_license_v1_0.lower(): freeimage_public_license_v1_0,
    freetype_project_license.lower(): freetype_project_license,
    fsf_all_permissive_license_without_warranty.lower(): fsf_all_permissive_license_without_warranty,
    fsf_all_permissive_license.lower(): fsf_all_permissive_license,
    fsf_unlimited_license_with_license_retention_and_warranty_disclaimer.lower(): fsf_unlimited_license_with_license_retention_and_warranty_disclaimer,
    fsf_unlimited_license_with_license_retention.lower(): fsf_unlimited_license_with_license_retention,
    fsf_unlimited_license.lower(): fsf_unlimited_license,
    fsfullrsd.lower(): fsfullrsd,
    fsl_1_1_alv2.lower(): fsl_1_1_alv2,
    fsl_1_1_mit.lower(): fsl_1_1_mit,
    furuseth_license.lower(): furuseth_license,
    fuzzy_bitmap_license.lower(): fuzzy_bitmap_license,
    fwlw_license.lower(): fwlw_license,
    game_programming_gems.lower(): game_programming_gems,
    gd_license.lower(): gd_license,
    generic_xts_license.lower(): generic_xts_license,
    giftware_license.lower(): giftware_license,
    gl2ps_license.lower(): gl2ps_license,
    glulxe_license.lower(): glulxe_license,
    gnome_gcr_documentation_license.lower(): gnome_gcr_documentation_license,
    gnu_affero_general_public_license_v1_0_only.lower(): gnu_affero_general_public_license_v1_0_only,
    gnu_affero_general_public_license_v1_0_or_later.lower(): gnu_affero_general_public_license_v1_0_or_later,
    gnu_affero_general_public_license_v2_0_only.lower(): gnu_affero_general_public_license_v2_0_only,
    gnu_affero_general_public_license_v2_0_or_later.lower(): gnu_affero_general_public_license_v2_0_or_later,
    gnu_affero_general_public_license_v3_0_only.lower(): gnu_affero_general_public_license_v3_0_only,
    gnu_affero_general_public_license_v3_0_or_later.lower(): gnu_affero_general_public_license_v3_0_or_later,
    gnu_affero.lower(): gnu_affero,
    gnu_free_documentation_license_v1_1_only___invariants.lower(): gnu_free_documentation_license_v1_1_only___invariants,
    gnu_free_documentation_license_v1_1_only___no_invariants.lower(): gnu_free_documentation_license_v1_1_only___no_invariants,
    gnu_free_documentation_license_v1_1_only.lower(): gnu_free_documentation_license_v1_1_only,
    gnu_free_documentation_license_v1_1_or_later___invariants.lower(): gnu_free_documentation_license_v1_1_or_later___invariants,
    gnu_free_documentation_license_v1_1_or_later___no_invariants.lower(): gnu_free_documentation_license_v1_1_or_later___no_invariants,
    gnu_free_documentation_license_v1_1_or_later.lower(): gnu_free_documentation_license_v1_1_or_later,
    gnu_free_documentation_license_v1_2_only___invariants.lower(): gnu_free_documentation_license_v1_2_only___invariants,
    gnu_free_documentation_license_v1_2_only___no_invariants.lower(): gnu_free_documentation_license_v1_2_only___no_invariants,
    gnu_free_documentation_license_v1_2_only.lower(): gnu_free_documentation_license_v1_2_only,
    gnu_free_documentation_license_v1_2_or_later___invariants.lower(): gnu_free_documentation_license_v1_2_or_later___invariants,
    gnu_free_documentation_license_v1_2_or_later___no_invariants.lower(): gnu_free_documentation_license_v1_2_or_later___no_invariants,
    gnu_free_documentation_license_v1_2_or_later.lower(): gnu_free_documentation_license_v1_2_or_later,
    gnu_free_documentation_license_v1_3_only___invariants.lower(): gnu_free_documentation_license_v1_3_only___invariants,
    gnu_free_documentation_license_v1_3_only___no_invariants.lower(): gnu_free_documentation_license_v1_3_only___no_invariants,
    gnu_free_documentation_license_v1_3_only.lower(): gnu_free_documentation_license_v1_3_only,
    gnu_free_documentation_license_v1_3_or_later___invariants.lower(): gnu_free_documentation_license_v1_3_or_later___invariants,
    gnu_free_documentation_license_v1_3_or_later___no_invariants.lower(): gnu_free_documentation_license_v1_3_or_later___no_invariants,
    gnu_free_documentation_license_v1_3_or_later.lower(): gnu_free_documentation_license_v1_3_or_later,
    gnu_general_public_license_v1_0_only.lower(): gnu_general_public_license_v1_0_only,
    gnu_general_public_license_v1_0_or_later.lower(): gnu_general_public_license_v1_0_or_later,
    gnu_general_public_license_v2_0_only.lower(): gnu_general_public_license_v2_0_only,
    gnu_general_public_license_v2_0_or_later.lower(): gnu_general_public_license_v2_0_or_later,
    gnu_general_public_license_v2_0_w_autoconf_exception.lower(): gnu_general_public_license_v2_0_w_autoconf_exception,
    gnu_general_public_license_v2_0_w_bison_exception.lower(): gnu_general_public_license_v2_0_w_bison_exception,
    gnu_general_public_license_v2_0_w_classpath_exception.lower(): gnu_general_public_license_v2_0_w_classpath_exception,
    gnu_general_public_license_v2_0_w_font_exception.lower(): gnu_general_public_license_v2_0_w_font_exception,
    gnu_general_public_license_v2_0_w_gcc_runtime_library_exception.lower(): gnu_general_public_license_v2_0_w_gcc_runtime_library_exception,
    gnu_general_public_license_v3_0_only.lower(): gnu_general_public_license_v3_0_only,
    gnu_general_public_license_v3_0_or_later.lower(): gnu_general_public_license_v3_0_or_later,
    gnu_general_public_license_v3_0_w_autoconf_exception.lower(): gnu_general_public_license_v3_0_w_autoconf_exception,
    gnu_general_public_license_v3_0_w_gcc_runtime_library_exception.lower(): gnu_general_public_license_v3_0_w_gcc_runtime_library_exception,
    gnu_lesser_general_public_license_v2_0_only.lower(): gnu_lesser_general_public_license_v2_0_only,
    gnu_lesser_general_public_license_v2_1_only.lower(): gnu_lesser_general_public_license_v2_1_only,
    gnu_lesser_general_public_license_v2_1_or_later.lower(): gnu_lesser_general_public_license_v2_1_or_later,
    gnu_lesser_general_public_license_v3_0_only.lower(): gnu_lesser_general_public_license_v3_0_only,
    gnu_lesser_general_public_license_v3_0_or_later.lower(): gnu_lesser_general_public_license_v3_0_or_later,
    gnu_lesser_general_public_license.lower(): gnu_lesser_general_public_license,
    gnu_library_general_public_license_v1_only.lower(): gnu_library_general_public_license_v1_only,
    gnu_library_general_public_license_v1_or_later.lower(): gnu_library_general_public_license_v1_or_later,
    gnu_library_general_public_license_v2_only.lower(): gnu_library_general_public_license_v2_only,
    gnu_library_general_public_license_v2_or_later.lower(): gnu_library_general_public_license_v2_or_later,
    gnu_public_license_v2.lower(): gnu_public_license_v2,
    gnu_public_license.lower(): gnu_public_license,
    gnuplot_license.lower(): gnuplot_license,
    good_luck_with_that_public_license.lower(): good_luck_with_that_public_license,
    graphics_gems_license.lower(): graphics_gems_license,
    gsoap_public_license_v1_3b.lower(): gsoap_public_license_v1_3b,
    gtkbook_license.lower(): gtkbook_license,
    gutmann_license.lower(): gutmann_license,
    haskell_language_report_license.lower(): haskell_language_report_license,
    hdf5.lower() : hdf5,
    hdparm_license.lower(): hdparm_license,
    hewlett_packard_1986_license.lower(): hewlett_packard_1986_license,
    hewlett_packard_1989_license.lower(): hewlett_packard_1989_license,
    hewlett_packard_bsd_variant_license.lower(): hewlett_packard_bsd_variant_license,
    hidapi_license.lower(): hidapi_license,
    hippocratic_license_2_1.lower(): hippocratic_license_2_1,
    historical_permission_notice_and_disclaimer___dec_variant.lower(): historical_permission_notice_and_disclaimer___dec_variant,
    historical_permission_notice_and_disclaimer___documentation_sell_variant.lower(): historical_permission_notice_and_disclaimer___documentation_sell_variant,
    historical_permission_notice_and_disclaimer___documentation_variant.lower(): historical_permission_notice_and_disclaimer___documentation_variant,
    historical_permission_notice_and_disclaimer___fenneberg_livingston_variant.lower(): historical_permission_notice_and_disclaimer___fenneberg_livingston_variant,
    historical_permission_notice_and_disclaimer___inria_imag_variant.lower(): historical_permission_notice_and_disclaimer___inria_imag_variant,
    historical_permission_notice_and_disclaimer___intel_variant.lower(): historical_permission_notice_and_disclaimer___intel_variant,
    historical_permission_notice_and_disclaimer___kevlin_henney_variant.lower(): historical_permission_notice_and_disclaimer___kevlin_henney_variant,
    historical_permission_notice_and_disclaimer___markus_kuhn_variant.lower(): historical_permission_notice_and_disclaimer___markus_kuhn_variant,
    historical_permission_notice_and_disclaimer___merchantability_variant.lower(): historical_permission_notice_and_disclaimer___merchantability_variant,
    historical_permission_notice_and_disclaimer___netrek_variant.lower(): historical_permission_notice_and_disclaimer___netrek_variant,
    historical_permission_notice_and_disclaimer___pbmplus_variant.lower(): historical_permission_notice_and_disclaimer___pbmplus_variant,
    historical_permission_notice_and_disclaimer___sell_regexpr_variant.lower(): historical_permission_notice_and_disclaimer___sell_regexpr_variant,
    historical_permission_notice_and_disclaimer___sell_variant.lower(): historical_permission_notice_and_disclaimer___sell_variant,
    historical_permission_notice_and_disclaimer___sell_xserver_variant_with_mit_disclaimer.lower(): historical_permission_notice_and_disclaimer___sell_xserver_variant_with_mit_disclaimer,
    historical_permission_notice_and_disclaimer___university_of_california__us_export_warning.lower(): historical_permission_notice_and_disclaimer___university_of_california__us_export_warning,
    historical_permission_notice_and_disclaimer___university_of_california_variant.lower(): historical_permission_notice_and_disclaimer___university_of_california_variant,
    historical_permission_notice_and_disclaimer_with_mit_disclaimer.lower(): historical_permission_notice_and_disclaimer_with_mit_disclaimer,
    historical_permission_notice.lower(): historical_permission_notice,
    hpnd_sell_variant_with_mit_disclaimer___reverse.lower(): hpnd_sell_variant_with_mit_disclaimer___reverse,
    hpnd_sell_variant_with_mit_disclaimer.lower(): hpnd_sell_variant_with_mit_disclaimer,
    hpnd_with_us_government_export_control_and_2_disclaimers.lower(): hpnd_with_us_government_export_control_and_2_disclaimers,
    hpnd_with_us_government_export_control_warning_and_acknowledgment.lower(): hpnd_with_us_government_export_control_warning_and_acknowledgment,
    hpnd_with_us_government_export_control_warning_and_modification_rqmt.lower(): hpnd_with_us_government_export_control_warning_and_modification_rqmt,
    hpnd_with_us_government_export_control_warning.lower(): hpnd_with_us_government_export_control_warning,
    html_tidy_license.lower(): html_tidy_license,
    ibm_powerpc_initialization_and_boot_software.lower(): ibm_powerpc_initialization_and_boot_software,
    ibm_public_license_v1_0.lower(): ibm_public_license_v1_0,
    icu_license.lower(): icu_license,
    iec_code_components_end_user_licence_agreement.lower(): iec_code_components_end_user_licence_agreement,
    imagemagick_license.lower(): imagemagick_license,
    imatix_standard_function_library_agreement.lower(): imatix_standard_function_library_agreement,
    imlib2_license.lower(): imlib2_license,
    independent_jpeg_group_license___short.lower(): independent_jpeg_group_license___short,
    independent_jpeg_group_license.lower(): independent_jpeg_group_license,
    info_zip_license.lower(): info_zip_license,
    inner_net_license_v2_0.lower(): inner_net_license_v2_0,
    inno_setup_license.lower(): inno_setup_license,
    intel_acpi_software_license_agreement.lower(): intel_acpi_software_license_agreement,
    intel_open_source_license.lower(): intel_open_source_license,
    interbase_public_license_v1_0.lower(): interbase_public_license_v1_0,
    ipa_font_license.lower(): ipa_font_license,
    isc_license.lower(): isc_license,
    isc_veillard_variant.lower(): isc_veillard_variant,
    jam_license.lower(): jam_license,
    japan_network_information_center_license.lower(): japan_network_information_center_license,
    jasper_license.lower(): jasper_license,
    jove.lower() : jove,
    jpl_image_use_policy.lower(): jpl_image_use_policy,
    json_license.lower(): json_license,
    kastrup_license.lower(): kastrup_license,
    kazlib_license.lower(): kazlib_license,
    knuth_ctan_license.lower(): knuth_ctan_license,
    latex_project_public_license_v1_0.lower(): latex_project_public_license_v1_0,
    latex_project_public_license_v1_1.lower(): latex_project_public_license_v1_1,
    latex_project_public_license_v1_2.lower(): latex_project_public_license_v1_2,
    latex_project_public_license_v1_3a.lower(): latex_project_public_license_v1_3a,
    latex_project_public_license_v1_3c.lower(): latex_project_public_license_v1_3c,
    latex2e_license.lower(): latex2e_license,
    latex2e_with_translated_notice_permission.lower(): latex2e_with_translated_notice_permission,
    lawrence_berkeley_national_labs_bsd_variant_license.lower(): lawrence_berkeley_national_labs_bsd_variant_license,
    leptonica_license.lower(): leptonica_license,
    lesser_general_public_license_for_linguistic_resources.lower(): lesser_general_public_license_for_linguistic_resources,
    libpng_1_6_35.lower(): libpng_1_6_35,
    libpng_license.lower(): libpng_license,
    libselinux_public_domain_notice.lower(): libselinux_public_domain_notice,
    libtiff_license.lower(): libtiff_license,
    libutil_david_nugent_license.lower(): libutil_david_nugent_license,
    licence_art_libre_1_2.lower(): licence_art_libre_1_2,
    licence_art_libre_1_3.lower(): licence_art_libre_1_3,
    licence_libre_du_québec_permissive_version_1_1.lower(): licence_libre_du_québec_permissive_version_1_1,
    licence_libre_du_québec_Réciprocité_forte_version_1_1.lower(): licence_libre_du_québec_Réciprocité_forte_version_1_1,
    licence_libre_du_québec_Réciprocité_version_1_1.lower(): licence_libre_du_québec_Réciprocité_version_1_1,
    linux_kernel_variant_of_openib_org_license.lower(): linux_kernel_variant_of_openib_org_license,
    linux_man_pages___1_paragraph.lower(): linux_man_pages___1_paragraph,
    linux_man_pages_copyleft___2_paragraphs.lower(): linux_man_pages_copyleft___2_paragraphs,
    linux_man_pages_copyleft_variant.lower(): linux_man_pages_copyleft_variant,
    linux_man_pages_copyleft.lower(): linux_man_pages_copyleft,
    lpd_documentation_license.lower(): lpd_documentation_license,
    lsof_license.lower(): lsof_license,
    lucent_public_license_v1_02.lower(): lucent_public_license_v1_02,
    lucent_public_license_version_1_0.lower(): lucent_public_license_version_1_0,
    lucida_bitmap_fonts_license.lower(): lucida_bitmap_fonts_license,
    lzma_sdk_license_versions_9_11_to_9_20.lower(): lzma_sdk_license_versions_9_11_to_9_20,
    lzma_sdk_license_versions_9_22_and_beyond.lower(): lzma_sdk_license_versions_9_22_and_beyond,
    mackerras_3_clause___acknowledgment_variant.lower(): mackerras_3_clause___acknowledgment_variant,
    mackerras_3_clause_license.lower(): mackerras_3_clause_license,
    magaz_license.lower(): magaz_license,
    mailprio_license.lower(): mailprio_license,
    makeindex_license.lower(): makeindex_license,
    man2html.lower(): man2html,
    martin_birgmeier_license.lower(): martin_birgmeier_license,
    matrix_template_library_license.lower(): matrix_template_library_license,
    mcphee_slideshow_license.lower(): mcphee_slideshow_license,
    metamail_license.lower(): metamail_license,
    michigan_merit_networks_license.lower(): michigan_merit_networks_license,
    microsoft_limited_public_license.lower(): microsoft_limited_public_license,
    microsoft_public_license.lower(): microsoft_public_license,
    microsoft_reciprocal_license.lower(): microsoft_reciprocal_license,
    minpack_license.lower(): minpack_license,
    mips_license.lower(): mips_license,
    mit_click_license.lower(): mit_click_license,
    mit_cmu.lower(): mit_cmu,
    mit_festival_variant.lower(): mit_festival_variant,
    mit_khronos___old_variant.lower(): mit_khronos___old_variant,
    mit_license_modern_variant.lower(): mit_license_modern_variant,
    mit_license.lower(): mit_license,
    mit_no_false_attribs_license.lower(): mit_no_false_attribs_license,
    mit_open_group_variant.lower(): mit_open_group_variant,
    mit_testregex_variant.lower(): mit_testregex_variant,
    mit_tom_wu_variant.lower(): mit_tom_wu_variant,
    mit_zero_license.lower(): mit_zero_license,
    mmixware_license.lower(): mmixware_license,
    motosoto_license.lower(): motosoto_license,
    mozilla_public_license_1_0.lower(): mozilla_public_license_1_0,
    mozilla_public_license_1_1.lower(): mozilla_public_license_1_1,
    mozilla_public_license_2_0_no_copyleft_exception.lower(): mozilla_public_license_2_0_no_copyleft_exception,
    mozilla_publice_license_v2.lower(): mozilla_publice_license_v2,
    mozilla_publice_license.lower(): mozilla_publice_license,
    mpeg_software_simulation.lower(): mpeg_software_simulation,
    mpi_permissive_license.lower(): mpi_permissive_license,
    mpich2_license.lower(): mpich2_license,
    mplus_font_license.lower(): mplus_font_license,
    mulan_permissive_software_license__version_1.lower(): mulan_permissive_software_license__version_1,
    mulan_permissive_software_license__version_2.lower(): mulan_permissive_software_license__version_2,
    multics_license.lower(): multics_license,
    mup_license.lower(): mup_license,
    nara_institute_of_science_and_technology_license_2003.lower(): nara_institute_of_science_and_technology_license_2003,
    nasa_open_source_agreement_1_3.lower(): nasa_open_source_agreement_1_3,
    naumen_public_license.lower(): naumen_public_license,
    ncbi_public_domain_notice.lower(): ncbi_public_domain_notice,
    ncl_source_code_license.lower(): ncl_source_code_license,
    net_boolean_public_license_v1.lower(): net_boolean_public_license_v1,
    net_snmp_license.lower(): net_snmp_license,
    netcdf_license.lower(): netcdf_license,
    nethack_general_public_license.lower(): nethack_general_public_license,
    netizen_open_source_license.lower(): netizen_open_source_license,
    netscape_public_license_v1_0.lower(): netscape_public_license_v1_0,
    netscape_public_license_v1_1.lower(): netscape_public_license_v1_1,
    newsletr_license.lower(): newsletr_license,
    ngrep.lower() : ngrep,
    nicta_public_software_license__version_1_0.lower(): nicta_public_software_license__version_1_0,
    nist_public_domain_notice_with_license_fallback.lower(): nist_public_domain_notice_with_license_fallback,
    nist_public_domain_notice.lower(): nist_public_domain_notice,
    nist_software_license.lower(): nist_software_license,
    no_limit_public_license.lower(): no_limit_public_license,
    nokia_open_source_license.lower(): nokia_open_source_license,
    non_commercial_government_licence.lower(): non_commercial_government_licence,
    non_profit_open_software_license_3_0.lower(): non_profit_open_software_license_3_0,
    norwegian_licence_for_open_government_data_nlod_1_0.lower(): norwegian_licence_for_open_government_data_nlod_1_0,
    norwegian_licence_for_open_government_data_nlod_2_0.lower(): norwegian_licence_for_open_government_data_nlod_2_0,
    noweb_license.lower(): noweb_license,
    nrl_license.lower(): nrl_license,
    ntia_pd.lower(): ntia_pd,
    ntp_license.lower(): ntp_license,
    ntp_no_attribution.lower(): ntp_no_attribution,
    nunit_license.lower(): nunit_license,
    oar_license.lower(): oar_license,
    oclc_research_public_license_2_0.lower(): oclc_research_public_license_2_0,
    offis_license.lower(): offis_license,
    ogc_software_license__version_1_0.lower(): ogc_software_license__version_1_0,
    open_cascade_technology_public_license.lower(): open_cascade_technology_public_license,
    open_data_commons_attribution_license_v1_0.lower(): open_data_commons_attribution_license_v1_0,
    open_data_commons_open_database_license_v1_0.lower(): open_data_commons_open_database_license_v1_0,
    open_data_commons_public_domain_dedication_and_license_1_0.lower(): open_data_commons_public_domain_dedication_and_license_1_0,
    open_government_licence___canada.lower(): open_government_licence___canada,
    open_government_licence_v1_0.lower(): open_government_licence_v1_0,
    open_government_licence_v2_0.lower(): open_government_licence_v2_0,
    open_government_licence_v3_0.lower(): open_government_licence_v3_0,
    open_group_test_suite_license.lower(): open_group_test_suite_license,
    open_ldap_public_license_2_2_2.lower(): open_ldap_public_license_2_2_2,
    open_ldap_public_license_v1_1.lower(): open_ldap_public_license_v1_1,
    open_ldap_public_license_v1_2.lower(): open_ldap_public_license_v1_2,
    open_ldap_public_license_v1_3.lower(): open_ldap_public_license_v1_3,
    open_ldap_public_license_v1_4.lower(): open_ldap_public_license_v1_4,
    open_ldap_public_license_v2_0_1.lower(): open_ldap_public_license_v2_0_1,
    open_ldap_public_license_v2_0_or_possibly_2_0a_and_2_0b.lower(): open_ldap_public_license_v2_0_or_possibly_2_0a_and_2_0b,
    open_ldap_public_license_v2_1.lower(): open_ldap_public_license_v2_1,
    open_ldap_public_license_v2_2_1.lower(): open_ldap_public_license_v2_2_1,
    open_ldap_public_license_v2_2.lower(): open_ldap_public_license_v2_2,
    open_ldap_public_license_v2_3.lower(): open_ldap_public_license_v2_3,
    open_ldap_public_license_v2_4.lower(): open_ldap_public_license_v2_4,
    open_ldap_public_license_v2_5.lower(): open_ldap_public_license_v2_5,
    open_ldap_public_license_v2_6.lower(): open_ldap_public_license_v2_6,
    open_ldap_public_license_v2_7.lower(): open_ldap_public_license_v2_7,
    open_ldap_public_license_v2_8.lower(): open_ldap_public_license_v2_8,
    open_logistics_foundation_license_version_1_3.lower(): open_logistics_foundation_license_version_1_3,
    open_market_license.lower(): open_market_license,
    open_public_license_v1_0.lower(): open_public_license_v1_0,
    open_publication_license_v1_0.lower(): open_publication_license_v1_0,
    open_software_license_1_0.lower(): open_software_license_1_0,
    open_software_license_1_1.lower(): open_software_license_1_1,
    open_software_license_2_0.lower(): open_software_license_2_0,
    open_software_license_2_1.lower(): open_software_license_2_1,
    open_software_license_3_0.lower(): open_software_license_3_0,
    open_use_of_data_agreement_v1_0.lower(): open_use_of_data_agreement_v1_0,
    openpbs_v2_3_software_license.lower(): openpbs_v2_3_software_license,
    openssl_license___standalone.lower(): openssl_license___standalone,
    openssl_license.lower(): openssl_license,
    openvision_license.lower(): openvision_license,
    oset_public_license_version_2_1.lower(): oset_public_license_version_2_1,
    padl_license.lower(): padl_license,
    peer_production_license.lower(): peer_production_license,
    php_license_v3_0.lower(): php_license_v3_0,
    php_license_v3_01.lower(): php_license_v3_01,
    pixar_license.lower(): pixar_license,
    pkgconf_license.lower(): pkgconf_license,
    plexus_classworlds_license.lower(): plexus_classworlds_license,
    png_reference_library_version_2.lower(): png_reference_library_version_2,
    pnmstitch_license.lower(): pnmstitch_license,
    polyform_noncommercial_license_1_0_0.lower(): polyform_noncommercial_license_1_0_0,
    polyform_small_business_license_1_0_0.lower(): polyform_small_business_license_1_0_0,
    postgresql_license.lower(): postgresql_license,
    psfrag_license.lower(): psfrag_license,
    psutils_license.lower(): psutils_license,
    public_domain.lower(): public_domain,
    python_ldap_license.lower(): python_ldap_license,
    python_license_2_0_1.lower(): python_license_2_0_1,
    python_license_2_0.lower(): python_license_2_0,
    python_license_v1.lower(): python_license_v1,
    python_license_v2.lower(): python_license_v2,
    python_license.lower(): python_license,
    q_public_license_1_0___inria_2004_variant.lower(): q_public_license_1_0___inria_2004_variant,
    q_public_license_1_0.lower(): q_public_license_1_0,
    qhull_license.lower(): qhull_license,
    radvd_license.lower(): radvd_license,
    rdisc_license.lower(): rdisc_license,
    realnetworks_public_source_license_v1_0.lower(): realnetworks_public_source_license_v1_0,
    reciprocal_public_license_1_1.lower(): reciprocal_public_license_1_1,
    reciprocal_public_license_1_5.lower(): reciprocal_public_license_1_5,
    red_hat_ecos_public_license_v1_1.lower(): red_hat_ecos_public_license_v1_1,
    repoze_license.lower(): repoze_license,
    ricoh_source_code_public_license.lower(): ricoh_source_code_public_license,
    rsa_message_digest_license.lower(): rsa_message_digest_license,
    ruby_license.lower(): ruby_license,
    ruby_pty_extension_license.lower(): ruby_pty_extension_license,
    sax_public_domain_notice_2_0.lower(): sax_public_domain_notice_2_0,
    sax_public_domain_notice.lower(): sax_public_domain_notice,
    saxpath_license.lower(): saxpath_license,
    scea_shared_source_license.lower(): scea_shared_source_license,
    scheme_language_report_license.lower(): scheme_language_report_license,
    scheme_widget_library_swl_software_license_agreement.lower(): scheme_widget_library_swl_software_license_agreement,
    secure_messaging_protocol_public_license.lower(): secure_messaging_protocol_public_license,
    sendmail_license_8_23.lower(): sendmail_license_8_23,
    sendmail_license.lower(): sendmail_license,
    sendmail_open_source_license_v1_1.lower(): sendmail_open_source_license_v1_1,
    server_side_public_license__v_1.lower(): server_side_public_license__v_1,
    sgi_free_software_license_b_v1_0.lower(): sgi_free_software_license_b_v1_0,
    sgi_free_software_license_b_v1_1.lower(): sgi_free_software_license_b_v1_1,
    sgi_free_software_license_b_v2_0.lower(): sgi_free_software_license_b_v2_0,
    sgi_opengl_license.lower(): sgi_opengl_license,
    sgp4_permission_notice.lower(): sgp4_permission_notice,
    sil_open_font_license_1_0_with_no_reserved_font_name.lower(): sil_open_font_license_1_0_with_no_reserved_font_name,
    sil_open_font_license_1_0_with_reserved_font_name.lower(): sil_open_font_license_1_0_with_reserved_font_name,
    sil_open_font_license_1_0.lower(): sil_open_font_license_1_0,
    sil_open_font_license_1_1_with_no_reserved_font_name.lower(): sil_open_font_license_1_1_with_no_reserved_font_name,
    sil_open_font_license_1_1_with_reserved_font_name.lower(): sil_open_font_license_1_1_with_reserved_font_name,
    sil_open_font_license_1_1.lower(): sil_open_font_license_1_1,
    simple_public_license_2_0.lower(): simple_public_license_2_0,
    sl_license.lower(): sl_license,
    sleepycat_license.lower(): sleepycat_license,
    smail_general_public_license.lower(): smail_general_public_license,
    snia_public_license_1_1.lower(): snia_public_license_1_1,
    snprintf_license.lower(): snprintf_license,
    sofa.lower() : sofa,
    softsurfer_license.lower(): softsurfer_license,
    solderpad_hardware_license__version_0_51.lower(): solderpad_hardware_license__version_0_51,
    solderpad_hardware_license_v0_5.lower(): solderpad_hardware_license_v0_5,
    soundex_license.lower(): soundex_license,
    spdx_3d_slicer_license_v1_0.lower(): spdx_3d_slicer_license_v1_0,
    spdx_3dfx_glide_license.lower(): spdx_3dfx_glide_license,
    spencer_license_86.lower(): spencer_license_86,
    spencer_license_94.lower(): spencer_license_94,
    spencer_license_99.lower(): spencer_license_99,
    sqlite_blessing.lower(): sqlite_blessing,
    ssh_keyscan_license.lower(): ssh_keyscan_license,
    ssh_openssh_license.lower(): ssh_openssh_license,
    ssh_short_notice.lower(): ssh_short_notice,
    ssleay_license___standalone.lower(): ssleay_license___standalone,
    standard_ml_of_new_jersey_license.lower(): standard_ml_of_new_jersey_license,
    sugarcrm_public_license_v1_1_3.lower(): sugarcrm_public_license_v1_1_3,
    sul_1_0.lower(): sul_1_0,
    sun_industry_standards_source_license_v1_1.lower(): sun_industry_standards_source_license_v1_1,
    sun_industry_standards_source_license_v1_2.lower(): sun_industry_standards_source_license_v1_2,
    sun_ppp_license_2000.lower(): sun_ppp_license_2000,
    sun_ppp_license.lower(): sun_ppp_license,
    sun_public_license_v1_0.lower(): sun_public_license_v1_0,
    sunpro_license.lower(): sunpro_license,
    swrule_license.lower(): swrule_license,
    sybase_open_watcom_public_license_1_0.lower(): sybase_open_watcom_public_license_1_0,
    symlinks_license.lower(): symlinks_license,
    systemics_bsd_variant_license.lower(): systemics_bsd_variant_license,
    systemics_w3works_bsd_variant_license.lower(): systemics_w3works_bsd_variant_license,
    taiwan_open_government_data_license__version_1_0.lower(): taiwan_open_government_data_license__version_1_0,
    tapr_open_hardware_license_v1_0.lower(): tapr_open_hardware_license_v1_0,
    tcl_tk_license.lower(): tcl_tk_license,
    tcp_wrappers_license.lower(): tcp_wrappers_license,
    technische_universitaet_berlin_license_1_0.lower(): technische_universitaet_berlin_license_1_0,
    technische_universitaet_berlin_license_2_0.lower(): technische_universitaet_berlin_license_2_0,
    termreadkey_license.lower(): termreadkey_license,
    text_tabswrap_license.lower(): text_tabswrap_license,
    the_miros_licence.lower(): the_miros_licence,
    the_parity_public_license_6_0_0.lower(): the_parity_public_license_6_0_0,
    the_parity_public_license_7_0_0.lower(): the_parity_public_license_7_0_0,
    thirdeye_license.lower(): thirdeye_license,
    thor_public_license_1_0.lower(): thor_public_license_1_0,
    threeparttable_license.lower(): threeparttable_license,
    time__parsedate_license.lower(): time__parsedate_license,
    tmate_open_source_license.lower(): tmate_open_source_license,
    torque_v2_5_software_license_v1_1.lower(): torque_v2_5_software_license_v1_1,
    transitive_grace_period_public_licence_1_0.lower(): transitive_grace_period_public_licence_1_0,
    trusster_open_source_license.lower(): trusster_open_source_license,
    trustedqsl_license.lower(): trustedqsl_license,
    ttyp0_license.lower(): ttyp0_license,
    ubuntu_font_licence_v1_0.lower(): ubuntu_font_licence_v1_0,
    ucar_license.lower(): ucar_license,
    ulem_license.lower(): ulem_license,
    unicode_license_agreement___data_files_and_software_2015.lower(): unicode_license_agreement___data_files_and_software_2015,
    unicode_license_agreement___data_files_and_software_2016.lower(): unicode_license_agreement___data_files_and_software_2016,
    unicode_license_v3.lower(): unicode_license_v3,
    unicode_terms_of_use.lower(): unicode_terms_of_use,
    united_kingdom_open_parliament_licence_v3_0.lower(): united_kingdom_open_parliament_licence_v3_0,
    universal_permissive_license_v1_0.lower(): universal_permissive_license_v1_0,
    universal_permissive_license.lower(): universal_permissive_license,
    university_of_illinois_ncsa_open_source_license.lower(): university_of_illinois_ncsa_open_source_license,
    unixcrypt_license.lower(): unixcrypt_license,
    unlicense_libtelnet.lower(): unlicense_libtelnet,
    unlicense_libwhirlpool.lower(): unlicense_libwhirlpool,
    unlicensed_license.lower(): unlicensed_license,
    upstream_compatibility_license_v1_0.lower(): upstream_compatibility_license_v1_0,
    utah_raster_toolkit_run_length_encoded_license.lower(): utah_raster_toolkit_run_length_encoded_license,
    vim_license.lower(): vim_license,
    vostrom_public_license_for_open_source.lower(): vostrom_public_license_for_open_source,
    vovida_software_license_v1_0.lower(): vovida_software_license_v1_0,
    w3c_software_notice_and_document_license_2015_05_13.lower(): w3c_software_notice_and_document_license_2015_05_13,
    w3c_software_notice_and_license_1998_07_20.lower(): w3c_software_notice_and_license_1998_07_20,
    w3c_software_notice_and_license_2002_12_31.lower(): w3c_software_notice_and_license_2002_12_31,
    w3m_license.lower(): w3m_license,
    widget_workshop_license.lower(): widget_workshop_license,
    wsuipa_license.lower(): wsuipa_license,
    wtf_you_want_license.lower(): wtf_you_want_license,
    wwl_license.lower(): wwl_license,
    wxwindows.lower(): wxwindows,
    x_net_license.lower(): x_net_license,
    x11_license_distribution_modification_variant.lower(): x11_license_distribution_modification_variant,
    x11_license.lower(): x11_license,
    x11_swapped_final_paragraphs.lower(): x11_swapped_final_paragraphs,
    xdebug_license_v_1_03.lower(): xdebug_license_v_1_03,
    xerox_license.lower(): xerox_license,
    xfig_license.lower(): xfig_license,
    xfree86_license_1_1.lower(): xfree86_license_1_1,
    xinetd_license.lower(): xinetd_license,
    xkeyboard_config_zinoviev_license.lower(): xkeyboard_config_zinoviev_license,
    xlock_license.lower(): xlock_license,
    xpp_license.lower(): xpp_license,
    xskat_license.lower(): xskat_license,
    xzoom_license.lower(): xzoom_license,
    yahoo_public_license_v1_0.lower(): yahoo_public_license_v1_0,
    yahoo_public_license_v1_1.lower(): yahoo_public_license_v1_1,
    zed_license.lower(): zed_license,
    zeeff_license.lower(): zeeff_license,
    zend_license_v2_0.lower(): zend_license_v2_0,
    zimbra_public_license_v1_3.lower(): zimbra_public_license_v1_3,
    zimbra_public_license_v1_4.lower(): zimbra_public_license_v1_4,
    zlib_libpng_license_with_acknowledgement.lower(): zlib_libpng_license_with_acknowledgement,
    zlib_license.lower(): zlib_license,
    zope_public_license_1_1.lower(): zope_public_license_1_1,
    zope_public_license_2_0.lower(): zope_public_license_2_0,
    zope_public_license_2_1.lower(): zope_public_license_2_1,
    zope_public_license_v1.lower(): zope_public_license_v1,
    zope_public_license_v2.lower(): zope_public_license_v2,
    zope_public_license.lower(): zope_public_license,
    '"apache 2.0"': apache_license_v2,
    'license :: osi approved :: mit license': mit_license,
    "['gplv3 or any later version']": gnu_general_public_license_v3_0_or_later,
    "0bsd" : bsd_license_c0,
    "2-bsd": bsd_license_c2,
    "2-clause bsd license": bsd_license_c2,
    "2-clause bsd": bsd_license_c2,
    "3-bsd": bsd_license_c3,
    "3-clause bsd <http://www.opensource.org/licenses/bsd-license.php>": bsd_license_c3,
    "3-clause bsd license": bsd_license_c3,
    "3-clause bsd": bsd_license_c3,
    "3d-slicer-1.0" : spdx_3d_slicer_license_v1_0,
    "aal" : attribution_assurance_license,
    "abstyles" : abstyles_license,
    "adacore-doc" : adacore_doc_license,
    "adobe-2006" : adobe_systems_incorporated_source_code_license_agreement,
    "adobe-display-postscript" : adobe_display_postscript_license,
    "adobe-glyph" : adobe_glyph_list_license,
    "adobe-utopia" : adobe_utopia_font_license,
    "adsl" : amazon_digital_services_license,
    "affero general public license v1.0 only": gnu_affero_general_public_license_v1_0_only,
    "affero general public license v1.0 or later": gnu_affero_general_public_license_v1_0_or_later,
    "affero general public license v1.0": gnu_affero_general_public_license_v1_0_only,
    "afl 1.1": academic_free_v1_1,
    "afl 1.2": academic_free_v1_2,
    "afl 2.0": academic_free_v2_0,
    "afl 2.1": academic_free_v2_1,
    "afl 3.0": academic_free_v3_0,
    "afl-1.1": academic_free_v1_1,
    "afl-1.2": academic_free_v1_2,
    "afl-2.0": academic_free_v2_0,
    "afl-2.1": academic_free_v2_1,
    "afl-3.0": academic_free_v3_0,
    "afl": academic_free,
    "afmparse" : afmparse_license,
    "agpl 3.0": gnu_affero_general_public_license_v3_0_only,
    "agpl v3": gnu_affero_general_public_license_v3_0_only,
    "agpl-1.0-only" : gnu_affero_general_public_license_v1_0_only,
    "agpl-1.0-or-later" : gnu_affero_general_public_license_v1_0_or_later,
    "agpl-1.0" : gnu_affero_general_public_license_v1_0_only,
    "agpl-3.0-only": gnu_affero_general_public_license_v3_0_only,
    "agpl-3.0-or-later" : gnu_affero_general_public_license_v3_0_or_later,
    "agpl-3.0": gnu_affero_general_public_license_v3_0_only,
    "agpl-3.0+": gnu_affero_general_public_license_v3_0_or_later,
    "agpl": gnu_affero,
    "agplv3 (see license file)": gnu_affero_general_public_license_v3_0_only,
    "agplv3": gnu_affero_general_public_license_v3_0_only,
    "aladdin" : aladdin_free_public_license,
    "amd-newlib" : amd_newlib_license,
    "amdplpa" : amds_plpa_map_c_license,
    "aml-glslang" : aml_glslang_variant_license,
    "aml" : apple_mit_license,
    "ampas" : academy_of_motion_picture_arts_and_sciences_bsd,
    "antlr-pd-fallback" : antlr_software_rights_notice_with_license_fallback,
    "antlr-pd" : antlr_software_rights_notice,
    "any-osi-perl-modules" : any_osi_license___perl_modules,
    "any-osi" : any_osi_license,
    "apache 2 license": apache_license_v2,
    "apache 2.0 license": apache_license_v2,
    "apache 2.0.": apache_license_v2,
    "apache 2.0": apache_license_v2,
    "apache 2": apache_license_v2,
    "apache licence 2.0": apache_license_v2,
    "apache license (2.0)": apache_license_v2,
    "apache license 2.0": apache_license_v2,
    "apache license 2": apache_license_v2,
    "apache license v2.0": apache_license_v2,
    "apache license version 2.0, january 2004 http://www.apache.org/licenses/": apache_license_v2,
    "apache license version 2.0": apache_license_v2,
    "apache license, v2.0": apache_license_v2,
    "apache license, version 2.0": apache_license_v2,
    "apache license": apache_license,
    "apache software license (apache 2.0)": apache_license_v2,
    "apache software license 2.0": apache_license_v2,
    "apache software license v1": apache_license_v1,
    "apache software license v2.0": apache_license_v2,
    "apache software license v2": apache_license_v2,
    "apache software license, version 2.0, http://www.apache.org/licenses/license-2.0": apache_license_v2,
    "apache software license": apache_license,
    "apache v2": apache_license_v2,
    "apache-1.0": apache_license_v1,
    "apache-1.1" : apache_license_1_1,
    "apache-2.0 license": apache_license_v2,
    "apache-2.0": apache_license_v2,
    "apache-2": apache_license_v2,
    "apache": apache_license,
    "apache2.0": apache_license_v2,
    "apache2": apache_license_v2,
    "apafml" : adobe_postscript_afm_license,
    "apgl3": gnu_affero_general_public_license_v3_0_only,
    "apl-1.0" : adaptive_public_license_1_0,
    "app-s2p" : app__s2p_license,
    "apsl-1.0" : apple_public_source_license_1_0,
    "apsl-1.1" : apple_public_source_license_1_1,
    "apsl-1.2" : apple_public_source_license_1_2,
    "apsl-2.0" : apple_public_source_license_2_0,
    "arphic-1999" : arphic_public_license,
    "artistic-1.0-cl8" : artistic_license_1_0_w_clause_8,
    "artistic-1.0-perl" : artistic_license_1_0_perl,
    "artistic-1.0" : artistic_license_1_0,
    "artistic-2.0" : artistic_license_2_0,
    "artistic-dist" : artistic_dist,
    "aspell-ru" : aspell_ru,
    "aswf-digital-assets-1.0" : aswf_digital_assets_license_version_1_0,
    "aswf-digital-assets-1.1" : aswf_digital_assets_license_1_1,
    "baekmuk" : baekmuk_license,
    "bahyph" : bahyph_license,
    "barr" : barr_license,
    "bcrypt-solar-designer" : bcrypt_solar_designer_license,
    "beerware" : beerware_license,
    "bitstream-charter" : bitstream_charter_font_license,
    "bitstream-vera" : bitstream_vera_font_license,
    "bittorrent-1.0" : bittorrent_open_source_license_v1_0,
    "bittorrent-1.1" : bittorrent_open_source_license_v1_1,
    "blessing" : sqlite_blessing,
    "blue oak model license (blueoak-1.0.0)" : blue_oak_model_license_1_0_0,
    "blueoak 1.0.0" : blue_oak_model_license_1_0_0,
    "blueoak-1.0.0" : blue_oak_model_license_1_0_0,
    "boehm-gc-without-fee" : boehm_demers_weiser_gc_license_without_fee,
    "boehm-gc" : boehm_demers_weiser_gc_license,
    "borceux" : borceux_license,
    "brian-gladman-2-clause" : brian_gladman_2_clause_license,
    "brian-gladman-3-clause" : brian_gladman_3_clause_license,
    "bsd (2-clause)": bsd_license_c2,
    "bsd (3-clause)": bsd_license_c3,
    "bsd 2-clause (see license file)": bsd_license_c2,
    "bsd 2-clause": bsd_license_c2,
    "bsd 3 clause": bsd_license_c3,
    "bsd 3-clause license": bsd_license_c3,
    "bsd 3-clause-license": bsd_license_c3,
    "bsd 3-clause": bsd_license_c3,
    "bsd 3": bsd_license_c3,
    "bsd license": bsd_license,
    "bsd zero clause license": bsd_license_c0,
    "bsd-1-clause" : bsd_1_clause_license,
    "bsd-2-clause license": bsd_license_c2,
    "bsd-2-clause-darwin" : bsd_2_clause___ian_darwin_variant,
    "bsd-2-clause-first-lines" : bsd_2_clause___first_lines_requirement,
    "bsd-2-clause-freebsd": bsd_2_clause__freebsd,
    "bsd-2-clause-license": bsd_license_c2,
    "bsd-2-clause-netbsd": bsd_2_clause__netbsd,
    "bsd-2-clause-patent" : bsd_2_clause_plus_patent_license,
    "bsd-2-clause-pkgconf-disclaimer" : bsd_2_clause_pkgconf_disclaimer,
    "bsd-2-clause-views" : bsd_2_clause_with_views_sentence,
    "bsd-2-clause": bsd_license_c2,
    "bsd-3-clause license": bsd_license_c3,
    "bsd-3-clause-acpica" : bsd_3_clause_acpica_variant,
    "bsd-3-clause-attribution" : bsd_with_attribution,
    "bsd-3-clause-clear" : bsd_3_clause_clear_license,
    "bsd-3-clause-flex" : bsd_3_clause_flex_variant,
    "bsd-3-clause-hp" : hewlett_packard_bsd_variant_license,
    "bsd-3-clause-lbnl" : lawrence_berkeley_national_labs_bsd_variant_license,
    "bsd-3-clause-license": bsd_license_c3,
    "bsd-3-clause-modification" : bsd_3_clause_modification,
    "bsd-3-clause-no-military-license" : bsd_3_clause_no_military_license,
    "bsd-3-clause-no-nuclear-license-2014" : bsd_3_clause_no_nuclear_license_2014,
    "bsd-3-clause-no-nuclear-license" : bsd_3_clause_no_nuclear_license,
    "bsd-3-clause-no-nuclear-warranty" : bsd_3_clause_no_nuclear_warranty,
    "bsd-3-clause-open-mpi" : bsd_3_clause_open_mpi_variant,
    "bsd-3-clause-sun" : bsd_3_clause_sun_microsystems,
    "bsd-3-clause": bsd_license_c3,
    "bsd-4-clause-shortened" : bsd_4_clause_shortened,
    "bsd-4-clause-uc" : bsd_4_clause_university_of_california_specific,
    "bsd-4-clause" : bsd_4_clause_original_or_old_license,
    "bsd-4.3reno" : bsd_4_3_reno_license,
    "bsd-4.3tahoe" : bsd_4_3_tahoe_license,
    "bsd-advertising-acknowledgement" : bsd_advertising_acknowledgement_license,
    "bsd-attribution-hpnd-disclaimer" : bsd_with_attribution_and_hpnd_disclaimer,
    "bsd-derived (http://www.repoze.org/license.txt)": repoze_license,
    "bsd-protection" : bsd_protection_license,
    "bsd-source-beginning-file" : bsd_source_code_attribution___beginning_of_file_variant,
    "bsd-source-code" : bsd_source_code_attribution,
    "bsd-systemics-w3works" : systemics_w3works_bsd_variant_license,
    "bsd-systemics" : systemics_bsd_variant_license,
    "bsd": bsd_license,
    "bsl-1.0" : boost_software_license_1_0,
    "busl-1.1" : business_source_license_1_1,
    "bzip2-1.0.5" : bzip2_and_libbzip2_license_v1_0_5,
    "bzip2-1.0.6" : bzip2_and_libbzip2_license_v1_0_6,
    "c-uda-1.0" : computational_use_of_data_agreement_v1_0,
    "cal-1.0-combined-work-exception" : cryptographic_autonomy_license_1_0_combined_work_exception,
    "cal-1.0" : cryptographic_autonomy_license_1_0,
    "caldera-no-preamble" : caldera_license_without_preamble,
    "caldera" : caldera_license,
    "catharon" : catharon_license,
    "catosl-1.1" : computer_associates_trusted_open_source_license_1_1,
    "cc-by-1.0" : creative_commons_attribution_1_0_generic,
    "cc-by-2.0" : creative_commons_attribution_2_0_generic,
    "cc-by-2.5-au" : creative_commons_attribution_2_5_australia,
    "cc-by-2.5" : creative_commons_attribution_2_5_generic,
    "cc-by-3.0-at" : creative_commons_attribution_3_0_austria,
    "cc-by-3.0-au" : creative_commons_attribution_3_0_australia,
    "cc-by-3.0-de" : creative_commons_attribution_3_0_germany,
    "cc-by-3.0-igo" : creative_commons_attribution_3_0_igo,
    "cc-by-3.0-nl" : creative_commons_attribution_3_0_netherlands,
    "cc-by-3.0-us" : creative_commons_attribution_3_0_united_states,
    "cc-by-3.0" : creative_commons_attribution_3_0_unported,
    "cc-by-4.0" : creative_commons_attribution_4_0_international,
    "cc-by-nc-1.0" : creative_commons_attribution_non_commercial_1_0_generic,
    "cc-by-nc-2.0" : creative_commons_attribution_non_commercial_2_0_generic,
    "cc-by-nc-2.5" : creative_commons_attribution_non_commercial_2_5_generic,
    "cc-by-nc-3.0-de" : creative_commons_attribution_non_commercial_3_0_germany,
    "cc-by-nc-3.0" : creative_commons_attribution_non_commercial_3_0_unported,
    "cc-by-nc-4.0" : creative_commons_attribution_non_commercial_4_0_international,
    "cc-by-nc-nd-1.0" : creative_commons_attribution_non_commercial_no_derivatives_1_0_generic,
    "cc-by-nc-nd-2.0" : creative_commons_attribution_non_commercial_no_derivatives_2_0_generic,
    "cc-by-nc-nd-2.5" : creative_commons_attribution_non_commercial_no_derivatives_2_5_generic,
    "cc-by-nc-nd-3.0-de" : creative_commons_attribution_non_commercial_no_derivatives_3_0_germany,
    "cc-by-nc-nd-3.0-igo" : creative_commons_attribution_non_commercial_no_derivatives_3_0_igo,
    "cc-by-nc-nd-3.0" : creative_commons_attribution_non_commercial_no_derivatives_3_0_unported,
    "cc-by-nc-nd-4.0" : creative_commons_attribution_non_commercial_no_derivatives_4_0_international,
    "cc-by-nc-sa-1.0" : creative_commons_attribution_non_commercial_share_alike_1_0_generic,
    "cc-by-nc-sa-2.0-de" : creative_commons_attribution_non_commercial_share_alike_2_0_germany,
    "cc-by-nc-sa-2.0-fr" : creative_commons_attribution_noncommercial_sharealike_2_0_france,
    "cc-by-nc-sa-2.0-uk" : creative_commons_attribution_non_commercial_share_alike_2_0_england_and_wales,
    "cc-by-nc-sa-2.0" : creative_commons_attribution_non_commercial_share_alike_2_0_generic,
    "cc-by-nc-sa-2.5" : creative_commons_attribution_non_commercial_share_alike_2_5_generic,
    "cc-by-nc-sa-3.0-de" : creative_commons_attribution_non_commercial_share_alike_3_0_germany,
    "cc-by-nc-sa-3.0-igo" : creative_commons_attribution_non_commercial_share_alike_3_0_igo,
    "cc-by-nc-sa-3.0" : creative_commons_attribution_non_commercial_share_alike_3_0_unported,
    "cc-by-nc-sa-4.0" : creative_commons_attribution_non_commercial_share_alike_4_0_international,
    "cc-by-nd-1.0" : creative_commons_attribution_no_derivatives_1_0_generic,
    "cc-by-nd-2.0" : creative_commons_attribution_no_derivatives_2_0_generic,
    "cc-by-nd-2.5" : creative_commons_attribution_no_derivatives_2_5_generic,
    "cc-by-nd-3.0-de" : creative_commons_attribution_no_derivatives_3_0_germany,
    "cc-by-nd-3.0" : creative_commons_attribution_no_derivatives_3_0_unported,
    "cc-by-nd-4.0" : creative_commons_attribution_no_derivatives_4_0_international,
    "cc-by-sa-1.0" : creative_commons_attribution_share_alike_1_0_generic,
    "cc-by-sa-2.0-uk" : creative_commons_attribution_share_alike_2_0_england_and_wales,
    "cc-by-sa-2.0" : creative_commons_attribution_share_alike_2_0_generic,
    "cc-by-sa-2.1-jp" : creative_commons_attribution_share_alike_2_1_japan,
    "cc-by-sa-2.5" : creative_commons_attribution_share_alike_2_5_generic,
    "cc-by-sa-3.0-at" : creative_commons_attribution_share_alike_3_0_austria,
    "cc-by-sa-3.0-de" : creative_commons_attribution_share_alike_3_0_germany,
    "cc-by-sa-3.0-igo" : creative_commons_attribution_sharealike_3_0_igo,
    "cc-by-sa-3.0" : creative_commons_attribution_share_alike_3_0_unported,
    "cc-by-sa-4.0" : creative_commons_attribution_share_alike_4_0_international,
    "cc-pddc" : creative_commons_public_domain_dedication_and_certification,
    "cc-pdm-1.0" : creative_commons_public_domain_mark_1_0_universal,
    "cc-sa-1.0" : creative_commons_share_alike_1_0_generic,
    "cc0 (copyright waived)": cc0_license,
    "cc0 1.0 universal (cc0 1.0) public domain dedication": cc0_license,
    "cc0 1.0 universal (cc0 1.0)": cc0_license,
    "cc0 1.0 universal": cc0_license,
    "cc0 1.0": cc0_license,
    "cc0-1.0" : creative_commons_zero_v1_0_universal,
    "cc0": cc0_license,
    "cddl-1.0" : common_development_and_distribution_license_1_0,
    "cddl-1.1" : common_development_and_distribution_license_1_1,
    "cdl-1.0" : common_documentation_license_1_0,
    "cdla-permissive-1.0" : community_data_license_agreement_permissive_1_0,
    "cdla-permissive-2.0" : community_data_license_agreement_permissive_2_0,
    "cdla-sharing-1.0" : community_data_license_agreement_sharing_1_0,
    "cecill-1.0" : cecill_free_software_license_agreement_v1_0,
    "cecill-1.1" : cecill_free_software_license_agreement_v1_1,
    "cecill-2.0" : cecill_free_software_license_agreement_v2_0,
    "cecill-2.1" : cecill_free_software_license_agreement_v2_1,
    "cecill-b" : cecill_b_free_software_license_agreement,
    "cecill-c" : cecill_c_free_software_license_agreement,
    "cern-ohl-1.1" : cern_open_hardware_licence_v1_1,
    "cern-ohl-1.2" : cern_open_hardware_licence_v1_2,
    "cern-ohl-p-2.0" : cern_open_hardware_licence_version_2___permissive,
    "cern-ohl-s-2.0" : cern_open_hardware_licence_version_2___strongly_reciprocal,
    "cern-ohl-w-2.0" : cern_open_hardware_licence_version_2___weakly_reciprocal,
    "cfitsio" : cfitsio_license,
    "check-cvs" : check_cvs_license,
    "checkmk" : checkmk_license,
    "clartistic" : clarified_artistic_license,
    "clips" : clips_license,
    "cmu license": mit_cmu,
    "cmu-license": mit_cmu,
    "cmu-mach-nodoc" : cmu_mach___no_notices_in_documentation_variant,
    "cmu-mach" : cmu_mach_license,
    "cnri-jython" : cnri_jython_license,
    "cnri-python-gpl-compatible" : cnri_python_open_source_gpl_compatible_license_agreement,
    "cnri-python" : cnri_python_license,
    "coil-1.0" : copyfree_open_innovation_license,
    "community-spec-1.0" : community_specification_license_1_0,
    "condor-1.1" : condor_public_license_v1_1,
    "copyleft-next-0.3.0" : copyleft_next_0_3_0,
    "copyleft-next-0.3.1" : copyleft_next_0_3_1,
    "cornell-lossless-jpeg" : cornell_lossless_jpeg_license,
    "cpal-1.0" : common_public_attribution_license_1_0,
    "cpl-1.0" : common_public_license_1_0,
    "cpol-1.02" : code_project_open_license_1_02,
    "Creative Commons Zero v1.0 Universal": cc0_license,
    "cronyx" : cronyx_license,
    "crossword" : crossword_license,
    "cryptoswift" : cryptoswift,
    "crystalstacker" : crystalstacker_license,
    "cua-opl-1.0" : cua_office_public_license_v1_0,
    "cube" : cube_license,
    "curl" : curl_license,
    "cve-tou" : common_vulnerability_enumeration_tou_license,
    "d-fsl-1.0" : deutsche_freie_software_lizenz,
    "data licence germany - attribution - version 2.0": data_licence_germany__attribution__version_2_0,
    "data licence germany - zero - version 2.0": data_licence_germany__zero__version_2_0,
    "data licence germany – attribution – version 2.0": data_licence_germany__attribution__version_2_0,
    "data licence germany – zero – version 2.0": data_licence_germany__zero__version_2_0,
    "dec-3-clause" : dec_3_clause_license,
    "diffmark" : diffmark_license,
    "dl-de-by-2.0" : data_licence_germany__attribution__version_2_0, 
    "dl-de-zero-2.0" : data_licence_germany__zero__version_2_0,
    "do what the f*ck you want to public license": wtf_you_want_license,
    "do what the f*ck you want to public": wtf_you_want_license,
    "doc" : doc_license,
    "docbook-dtd" : docbook_dtd,
    "docbook-schema" : docbook_schema_license,
    "docbook-stylesheet" : docbook_stylesheet_license,
    "docbook-xml" : docbook_xml_license,
    "dotseqn" : dotseqn_license,
    "drl-1.0" : detection_rule_license_1_0,
    "drl-1.1" : detection_rule_license_1_1,
    "dsdp" : dsdp_license,
    "dtoa" : david_m__gay_dtoa_license,
    "dvipdfm" : dvipdfm_license,
    "ecl-1.0" : educational_community_license_v1_0,
    "ecl-2.0" : educational_community_license_v2_0,
    "eclipse public license 1.0 (epl-1.0)": eclipse_public_license_v1,
    "eclipse public license 1.0": eclipse_public_license_v1,
    "eclipse public license 2.0 (epl-2.0)": eclipse_public_license_v2,
    "eclipse public license 2.0": eclipse_public_license_v2,
    "eclipse public license v2.0 / eclipse distribution license v1.0": eclipse_public_license_v2,
    "eclipse public license v2.0": eclipse_public_license_v2,
    "ecos-2.0": ecos_license_v2_0,
    "efl-1.0" : eiffel_forum_license_v1_0,
    "efl-2.0" : eiffel_forum_license_v2_0,
    "egenix" : egenix_com_public_license_1_1_0,
    "elastic-2.0" : elastic_license_2_0,
    "entessa" : entessa_public_license_v1_0,
    "epics" : epics_open_license,
    "epl-1.0" : eclipse_public_license_v1,
    "epl-2.0" : eclipse_public_license_v2,
    "erlpl-1.1" : erlang_public_license_v1_1,
    "etalab-2.0" : etalab_open_license_2_0,
    "eudatagrid" : eu_datagrid_software_license,
    "eupl-1.0" : european_union_public_license_1_0,
    "eupl-1.1" : european_union_public_license_1_1,
    "eupl-1.2" : european_union_public_license_1_2,
    "eurosym" : eurosym_license,
    "expat license": mit_license,
    "expat": mit_license,
    "fair" : fair_license,
    "fbm" : fuzzy_bitmap_license,
    "fdk-aac" : fraunhofer_fdk_aac_codec_library,
    "ferguson-twofish" : ferguson_twofish_license,
    "frameworx-1.0" : frameworx_open_license_1_0,
    "free bsd license" : bsd_2_clause__freebsd, # Source: https://opensource.org/license/BSD-2-Clause
    "free bsd" : bsd_2_clause__freebsd, # Source: https://opensource.org/license/BSD-2-Clause
    "freebsd license" : bsd_2_clause__freebsd, # Source: https://opensource.org/license/BSD-2-Clause
    "freebsd-doc" : freebsd_documentation_license,
    "freebsd" : bsd_2_clause__freebsd, # Source: https://opensource.org/license/BSD-2-Clause
    "freeimage" : freeimage_public_license_v1_0,
    "fsfap-no-warranty-disclaimer" : fsf_all_permissive_license_without_warranty,
    "fsfap" : fsf_all_permissive_license,
    "fsful" : fsf_unlimited_license,
    "fsfullr" : fsf_unlimited_license_with_license_retention,
    "fsfullrsd" : fsfullrsd,
    "fsfullrwd" : fsf_unlimited_license_with_license_retention_and_warranty_disclaimer,
    "fsl-1.1-alv2" : fsl_1_1_alv2,
    "fsl-1.1-mit" : fsl_1_1_mit,
    "ftl" : freetype_project_license,
    "furuseth" : furuseth_license,
    "fwlw" : fwlw_license,
    "game-programming-gems" : game_programming_gems,
    "gcr-docs" : gnome_gcr_documentation_license,
    "gd" : gd_license,
    "generic-xts" : generic_xts_license,
    "gfdl-1.1-invariants-only" : gnu_free_documentation_license_v1_1_only___invariants,
    "gfdl-1.1-invariants-or-later" : gnu_free_documentation_license_v1_1_or_later___invariants,
    "gfdl-1.1-no-invariants-only" : gnu_free_documentation_license_v1_1_only___no_invariants,
    "gfdl-1.1-no-invariants-or-later" : gnu_free_documentation_license_v1_1_or_later___no_invariants,
    "gfdl-1.1-only" : gnu_free_documentation_license_v1_1_only,
    "gfdl-1.1-or-later" : gnu_free_documentation_license_v1_1_or_later,
    "gfdl-1.1" : gnu_free_documentation_license_v1_1_only,
    "gfdl-1.2-invariants-only" : gnu_free_documentation_license_v1_2_only___invariants,
    "gfdl-1.2-invariants-or-later" : gnu_free_documentation_license_v1_2_or_later___invariants,
    "gfdl-1.2-no-invariants-only" : gnu_free_documentation_license_v1_2_only___no_invariants,
    "gfdl-1.2-no-invariants-or-later" : gnu_free_documentation_license_v1_2_or_later___no_invariants,
    "gfdl-1.2-only" : gnu_free_documentation_license_v1_2_only,
    "gfdl-1.2-or-later" : gnu_free_documentation_license_v1_2_or_later,
    "gfdl-1.2" : gnu_free_documentation_license_v1_2_only,
    "gfdl-1.3-invariants-only" : gnu_free_documentation_license_v1_3_only___invariants,
    "gfdl-1.3-invariants-or-later" : gnu_free_documentation_license_v1_3_or_later___invariants,
    "gfdl-1.3-no-invariants-only" : gnu_free_documentation_license_v1_3_only___no_invariants,
    "gfdl-1.3-no-invariants-or-later" : gnu_free_documentation_license_v1_3_or_later___no_invariants,
    "gfdl-1.3-only" : gnu_free_documentation_license_v1_3_only,
    "gfdl-1.3-or-later" : gnu_free_documentation_license_v1_3_or_later,
    "gfdl-1.3" : gnu_free_documentation_license_v1_3_only,
    "giftware" : giftware_license,
    "gl2ps" : gl2ps_license,
    "glide" : spdx_3dfx_glide_license,
    "glulxe" : glulxe_license,
    "glwtpl" : good_luck_with_that_public_license,
    "gnu 3.0": gnu_general_public_license_v3_0_only,
    "gnu affero general public license v3 (aplv3)": gnu_affero_general_public_license_v3_0_only,
    "gnu affero general public license v3 or later (agplv3+)": gnu_affero_general_public_license_v3_0_or_later,
    "gnu affero general public license v3.0": gnu_affero_general_public_license_v3_0_only,
    "gnu affero general public license v3": gnu_affero_general_public_license_v3_0_only,
    "gnu affero general public license version 3 (agpl-3.0)": gnu_affero_general_public_license_v3_0_only,
    "gnu affero general public license, version 3": gnu_affero_general_public_license_v3_0_only,
    "gnu affero gpl 3.0": gnu_affero_general_public_license_v3_0_only,
    "gnu agplv3": gnu_affero_general_public_license_v3_0_only,
    "gnu free documentation license v1.1": gnu_free_documentation_license_v1_1_only,
    "gnu free documentation license v1.2": gnu_free_documentation_license_v1_2_only,
    "gnu free documentation license v1.3": gnu_free_documentation_license_v1_3_only,
    "gnu general license version 3": gnu_general_public_license_v3_0_only,
    "gnu general public licence v3.0": gnu_general_public_license_v3_0_only,
    "gnu general public license (gpl)": gnu_public_license,
    "gnu general public license v2 (gplv2)": gnu_public_license_v2,
    "gnu general public license v2 or later (gplv2+)": gnu_general_public_license_v2_0_or_later,
    "gnu general public license v2.0": gnu_public_license_v2,
    "gnu general public license v3 (gplv3)": gnu_general_public_license_v3_0_only,
    "gnu general public license v3 or later (gplv3+)": gnu_general_public_license_v3_0_or_later,
    "gnu general public license v3 or later": gnu_affero_general_public_license_v3_0_or_later,
    "gnu general public license v3.0": gnu_general_public_license_v3_0_only,
    "gnu general public license v3": gnu_general_public_license_v3_0_only,
    "gnu general public license version 3 or later (gplv3+)": gnu_affero_general_public_license_v3_0_or_later,
    "gnu general public license, version 3, 29 june 2007": gnu_general_public_license_v3_0_only,
    "gnu general public license, version 3": gnu_general_public_license_v3_0_only,
    "gnu general public license": gnu_public_license,
    "gnu gpl 3.0": gnu_general_public_license_v3_0_only,
    "gnu gpl v2 or later": gnu_general_public_license_v2_0_or_later,
    "gnu gpl v3.0": gnu_general_public_license_v3_0_only,
    "gnu gpl v3": gnu_general_public_license_v3_0_only,
    "gnu gpl version 3": gnu_general_public_license_v3_0_only,
    "gnu gplv2": gnu_public_license_v2,
    "gnu gplv3 or any higher": gnu_general_public_license_v3_0_only,
    "gnu gplv3": gnu_general_public_license_v3_0_only,
    "gnu lesser general public license (lgpl)": gnu_lesser_general_public_license,
    "gnu lesser general public license v2 (lgplv2)": gnu_lesser_general_public_license_v2_0_only,
    "gnu lesser general public license v2 or later (lgplv2+)": gnu_general_public_license_v2_0_or_later,
    "gnu lesser general public license v2": gnu_lesser_general_public_license_v2_0_only,
    "gnu lesser general public license v3 (lgplv3)": gnu_lesser_general_public_license_v3_0_only,
    "gnu lesser general public license v3 or later (lgplv3+)": gnu_lesser_general_public_license_v3_0_or_later,
    "gnu lesser general public license v3": gnu_lesser_general_public_license_v3_0_only,
    "gnu lgpl": gnu_lesser_general_public_license,
    "gnu library or lesser general public license (lgpl)": gnu_lesser_general_public_license,
    "gnu-gpl": gnu_public_license,
    "gnu-gplv3": gnu_general_public_license_v3_0_only,
    "gnu": gnu_public_license,
    "gnuplot" : gnuplot_license,
    "gnuv3": gnu_general_public_license_v3_0_only,
    "gpl 2.0": gnu_public_license_v2,
    "gpl 2.0/lgpl 2.1": gnu_lesser_general_public_license_v2_1_only,
    "gpl 2": gnu_public_license_v2,
    "gpl 3.0": gnu_general_public_license_v3_0_only,
    "gpl 3": gnu_general_public_license_v3_0_only,
    "gpl license": gnu_public_license,
    "gpl v2": gnu_public_license_v2,
    "gpl v3": gnu_general_public_license_v3_0_only,
    "gpl version 2": gnu_public_license_v2,
    "gpl version 3": gnu_general_public_license_v3_0_only,
    "gpl-1.0-only" : gnu_general_public_license_v1_0_only,
    "gpl-1.0-or-later" : gnu_general_public_license_v1_0_or_later,
    "gpl-1.0": gnu_general_public_license_v1_0_only,
    "gpl-1.0+": gnu_general_public_license_v1_0_or_later,
    "gpl-2.0-only" : gnu_general_public_license_v2_0_only,
    "gpl-2.0-or-later or agpl-3.0-or-later or cern-ohl-s-2.0+": gnu_public_license, # TODO remove when #24 is fixed
    "gpl-2.0-or-later" : gnu_general_public_license_v2_0_or_later,
    "gpl-2.0-with-autoconf-exception" : gnu_general_public_license_v2_0_w_autoconf_exception,
    "gpl-2.0-with-bison-exception" : gnu_general_public_license_v2_0_w_bison_exception,
    "gpl-2.0-with-classpath-exception" : gnu_general_public_license_v2_0_w_classpath_exception,
    "gpl-2.0-with-font-exception" : gnu_general_public_license_v2_0_w_font_exception,
    "gpl-2.0-with-gcc-exception" : gnu_general_public_license_v2_0_w_gcc_runtime_library_exception,
    "gpl-2.0": gnu_public_license_v2,
    "gpl-2.0+": gnu_general_public_license_v2_0_or_later,
    "gpl-2": gnu_public_license_v2,
    "gpl-3.0 license": gnu_general_public_license_v3_0_only,
    "gpl-3.0-only" : gnu_general_public_license_v3_0_only,
    "gpl-3.0-or-later": gnu_general_public_license_v3_0_or_later,
    "gpl-3.0-orlater": gnu_general_public_license_v3_0_or_later,
    "gpl-3.0-with-autoconf-exception" : gnu_general_public_license_v3_0_w_autoconf_exception,
    "gpl-3.0-with-gcc-exception" : gnu_general_public_license_v3_0_w_gcc_runtime_library_exception,
    "gpl-3.0": gnu_general_public_license_v3_0_only,
    "gpl-3.0+": gnu_general_public_license_v3_0_or_later,
    "gpl-3": gnu_general_public_license_v3_0_only,
    "gpl-v3": gnu_general_public_license_v3_0_only,
    "gpl": gnu_public_license,
    "gpl>=3": gnu_general_public_license_v3_0_only,
    "gpl2": gnu_public_license_v2,
    "gpl3.0": gnu_general_public_license_v3_0_only,
    "gpl3": gnu_general_public_license_v3_0_only,
    "gpl3+": gnu_general_public_license_v3_0_or_later,
    "gplv03": gnu_general_public_license_v3_0_only,
    "gplv2": gnu_public_license_v2,
    "gplv2+": gnu_general_public_license_v2_0_or_later,
    "gplv3 license": gnu_general_public_license_v3_0_only,
    "gplv3": gnu_general_public_license_v3_0_only,
    "gplv3+": gnu_general_public_license_v3_0_or_later,
    "graphics-gems" : graphics_gems_license,
    "gsoap-1.3b" : gsoap_public_license_v1_3b,
    "gtkbook" : gtkbook_license,
    "gutmann" : gutmann_license,
    "haskellreport" : haskell_language_report_license,
    "hdf5" : hdf5,
    "hdparm" : hdparm_license,
    "hidapi" : hidapi_license,
    "hippocratic-2.1" : hippocratic_license_2_1,
    "historical permission notice and disclaimer (hpnd)": historical_permission_notice,
    "historical permission notice and disclaimer": historical_permission_notice,
    "hp-1986" : hewlett_packard_1986_license,
    "hp-1989" : hewlett_packard_1989_license,
    "hpnd-dec" : historical_permission_notice_and_disclaimer___dec_variant,
    "hpnd-doc-sell" : historical_permission_notice_and_disclaimer___documentation_sell_variant,
    "hpnd-doc" : historical_permission_notice_and_disclaimer___documentation_variant,
    "hpnd-export-us-acknowledgement" : hpnd_with_us_government_export_control_warning_and_acknowledgment,
    "hpnd-export-us-modify" : hpnd_with_us_government_export_control_warning_and_modification_rqmt,
    "hpnd-export-us" : hpnd_with_us_government_export_control_warning,
    "hpnd-export2-us" : hpnd_with_us_government_export_control_and_2_disclaimers,
    "hpnd-fenneberg-livingston" : historical_permission_notice_and_disclaimer___fenneberg_livingston_variant,
    "hpnd-inria-imag" : historical_permission_notice_and_disclaimer___inria_imag_variant,
    "hpnd-intel" : historical_permission_notice_and_disclaimer___intel_variant,
    "hpnd-kevlin-henney" : historical_permission_notice_and_disclaimer___kevlin_henney_variant,
    "hpnd-markus-kuhn" : historical_permission_notice_and_disclaimer___markus_kuhn_variant,
    "hpnd-merchantability-variant" : historical_permission_notice_and_disclaimer___merchantability_variant,
    "hpnd-mit-disclaimer" : historical_permission_notice_and_disclaimer_with_mit_disclaimer,
    "hpnd-netrek" : historical_permission_notice_and_disclaimer___netrek_variant,
    "hpnd-pbmplus" : historical_permission_notice_and_disclaimer___pbmplus_variant,
    "hpnd-sell-mit-disclaimer-xserver" : historical_permission_notice_and_disclaimer___sell_xserver_variant_with_mit_disclaimer,
    "hpnd-sell-regexpr" : historical_permission_notice_and_disclaimer___sell_regexpr_variant,
    "hpnd-sell-variant-mit-disclaimer-rev" : hpnd_sell_variant_with_mit_disclaimer___reverse,
    "hpnd-sell-variant-mit-disclaimer" : hpnd_sell_variant_with_mit_disclaimer,
    "hpnd-sell-variant" : historical_permission_notice_and_disclaimer___sell_variant,
    "hpnd-uc-export-us" : historical_permission_notice_and_disclaimer___university_of_california__us_export_warning,
    "hpnd-uc" : historical_permission_notice_and_disclaimer___university_of_california_variant,
    "hpnd": historical_permission_notice,
    "htmltidy" : html_tidy_license,
    "http://www.apache.org/licenses/license-2.0": apache_license_v2,
    "http://www.opensource.org/licenses/mit-license.php": mit_license,
    "https://aka.ms/azureml-sdk-license": azure_license,
    "https://www.gnu.org/licenses/gpl-3.0.txt": gnu_general_public_license_v3_0_only,
    "https://www.gnu.org/licenses/lgpl.html": gnu_lesser_general_public_license_v3_0_only,
    "ibm-pibs" : ibm_powerpc_initialization_and_boot_software,
    "icu" : icu_license,
    "iec-code-components-eula" : iec_code_components_end_user_licence_agreement,
    "ijg-short" : independent_jpeg_group_license___short,
    "ijg" : independent_jpeg_group_license,
    "imagemagick" : imagemagick_license,
    "imatix" : imatix_standard_function_library_agreement,
    "imlib2" : imlib2_license,
    "info-zip" : info_zip_license,
    "inner-net-2.0" : inner_net_license_v2_0,
    "innosetup" : inno_setup_license,
    "intel-acpi" : intel_acpi_software_license_agreement,
    "intel" : intel_open_source_license,
    "interbase-1.0" : interbase_public_license_v1_0,
    "ipa" : ipa_font_license,
    "ipl-1.0" : ibm_public_license_v1_0,
    "isc license (iscl)": isc_license,
    "isc-veillard" : isc_veillard_variant,
    "isc": isc_license,
    "iscl": isc_license,
    "jam" : jam_license,
    "jasper-2.0" : jasper_license,
    "jove" : jove,
    "jpl-image" : jpl_image_use_policy,
    "jpnic" : japan_network_information_center_license,
    "json" : json_license,
    "kastrup" : kastrup_license,
    "kazlib" : kazlib_license,
    "knuth-ctan" : knuth_ctan_license,
    "lal-1.2" : licence_art_libre_1_2,
    "lal-1.3" : licence_art_libre_1_3,
    "latex2e-translated-notice" : latex2e_with_translated_notice_permission,
    "latex2e" : latex2e_license,
    "leptonica" : leptonica_license,
    "lgpl 2.0": gnu_lesser_general_public_license_v2_1_only,
    "lgpl v3": gnu_lesser_general_public_license_v3_0_only,
    "lgpl-1.0-only" : gnu_library_general_public_license_v1_only,
    "lgpl-1.0-or-later" : gnu_library_general_public_license_v1_or_later,
    "lgpl-1.0" : gnu_library_general_public_license_v1_only,
    "lgpl-1.0+" : gnu_library_general_public_license_v1_or_later,
    "lgpl-2.0-only" : gnu_library_general_public_license_v2_only,
    "lgpl-2.0-or-later" : gnu_library_general_public_license_v2_or_later,
    "lgpl-2.0" : gnu_library_general_public_license_v2_only,
    "lgpl-2.0+": gnu_general_public_license_v2_0_or_later,
    "lgpl-2.1 license": gnu_lesser_general_public_license_v2_1_only,
    "lgpl-2.1-only": gnu_lesser_general_public_license_v2_1_only,
    "lgpl-2.1-or-later" : gnu_lesser_general_public_license_v2_1_or_later,
    "lgpl-2.1": gnu_lesser_general_public_license_v2_1_only,
    "lgpl-2.1+": gnu_lesser_general_public_license_v2_1_or_later,
    "lgpl-3.0 license": gnu_lesser_general_public_license_v3_0_only,
    "lgpl-3.0-only" : gnu_lesser_general_public_license_v3_0_only,
    "lgpl-3.0-or-later": gnu_lesser_general_public_license_v3_0_or_later,
    "lgpl-3.0": gnu_lesser_general_public_license_v3_0_only,
    "lgpl-3.0+": gnu_lesser_general_public_license_v3_0_or_later,
    "lgpl, see also license.txt": gnu_lesser_general_public_license,
    "lgpl": gnu_lesser_general_public_license,
    "lgpl3": gnu_lesser_general_public_license_v3_0_only,
    "lgpllr" : lesser_general_public_license_for_linguistic_resources,
    "lgplv2": gnu_general_public_license_v2_0_only,
    "lgplv2+": gnu_general_public_license_v2_0_or_later,
    "lgplv3": gnu_lesser_general_public_license_v3_0_only,
    "lgplv3+": gnu_lesser_general_public_license_v3_0_or_later,
    "libpng-1.6.35" : libpng_1_6_35,
    "libpng-2.0" : png_reference_library_version_2,
    "libpng" : libpng_license,
    "libselinux-1.0" : libselinux_public_domain_notice,
    "libtiff" : libtiff_license,
    "libutil-david-nugent" : libutil_david_nugent_license,
    "licence libre du québec - permissive version 1.1": licence_libre_du_québec_permissive_version_1_1,
    "licence libre du québec - réciprocité forte version 1.1": licence_libre_du_québec_Réciprocité_forte_version_1_1,
    "licence libre du québec - réciprocité version 1.1": licence_libre_du_québec_Réciprocité_version_1_1,
    "licence libre du québec – permissive version 1.1": licence_libre_du_québec_permissive_version_1_1,
    "licence libre du québec – réciprocité forte version 1.1": licence_libre_du_québec_Réciprocité_forte_version_1_1,
    "licence libre du québec – réciprocité version 1.1": licence_libre_du_québec_Réciprocité_version_1_1,
    "license :: osi approved :: apache software license": apache_license,
    "liliq-p-1.1" : licence_libre_du_québec_permissive_version_1_1,
    "liliq-r-1.1" : licence_libre_du_québec_Réciprocité_forte_version_1_1,
    "liliq-rplus-1.1" : licence_libre_du_québec_Réciprocité_version_1_1,
    "linux-man-pages-1-para" : linux_man_pages___1_paragraph,
    "linux-man-pages-copyleft-2-para" : linux_man_pages_copyleft___2_paragraphs,
    "linux-man-pages-copyleft-var" : linux_man_pages_copyleft_variant,
    "linux-man-pages-copyleft" : linux_man_pages_copyleft,
    "linux-openib" : linux_kernel_variant_of_openib_org_license,
    "loop" : common_lisp_loop_license,
    "lpd-document" : lpd_documentation_license,
    "lpl-1.0" : lucent_public_license_version_1_0,
    "lpl-1.02" : lucent_public_license_v1_02,
    "lppl-1.0" : latex_project_public_license_v1_0,
    "lppl-1.1" : latex_project_public_license_v1_1,
    "lppl-1.2" : latex_project_public_license_v1_2,
    "lppl-1.3a" : latex_project_public_license_v1_3a,
    "lppl-1.3c" : latex_project_public_license_v1_3c,
    "lsof" : lsof_license,
    "lucida-bitmap-fonts" : lucida_bitmap_fonts_license,
    "lzma-sdk-9.11-to-9.20" : lzma_sdk_license_versions_9_11_to_9_20,
    "lzma-sdk-9.22" : lzma_sdk_license_versions_9_22_and_beyond,
    "mackerras-3-clause-acknowledgment" : mackerras_3_clause___acknowledgment_variant,
    "mackerras-3-clause" : mackerras_3_clause_license,
    "magaz" : magaz_license,
    "mailprio" : mailprio_license,
    "makeindex" : makeindex_license,
    "man2html" : man2html,
    "martin-birgmeier" : martin_birgmeier_license,
    "mcphee-slideshow" : mcphee_slideshow_license,
    "metamail" : metamail_license,
    "minpack" : minpack_license,
    "mips" : mips_license,
    "miros" : the_miros_licence,
    "mit -  see license.txt": mit_license,
    "mit 0": mit_zero_license,
    "mit licence": mit_license,
    "mit license ": mit_license,
    "mit license (mit)": mit_license,
    "mit license": mit_license,
    "mit licensed, as found in the license file": mit_license,
    "mit no attribution license (mit-0)": mit_zero_license,
    "mit no attribution license": mit_zero_license,
    "mit-0 license": mit_zero_license,
    "mit-0": mit_zero_license,
    "mit-advertising" : enlightenment_license_e16,
    "mit-click" : mit_click_license,
    "mit-cmu": mit_cmu,
    "mit-enna" : enna_license,
    "mit-feh" : feh_license,
    "mit-festival" : mit_festival_variant,
    "mit-khronos-old" : mit_khronos___old_variant,
    "mit-modern-variant" : mit_license_modern_variant,
    "mit-open-group" : mit_open_group_variant,
    "mit-testregex" : mit_testregex_variant,
    "mit-wu" : mit_tom_wu_variant,
    "mit": mit_license,
    "mitnfa" : mit_no_false_attribs_license,
    "mmixware" : mmixware_license,
    "modified bsd license": bsd_3_clause_modification, # Source: https://opensource.org/license/BSD-3-Clause
    "modified bsd": bsd_3_clause_modification, # Source: https://opensource.org/license/BSD-3-Clause
    "motosoto" : motosoto_license,
    "mozilla public license 1.1 (mpl 1.1)": mozilla_public_license_1_1,
    "mozilla public license 2.0 (mpl 2.0)": mozilla_publice_license_v2,
    "mozilla public license 2.0": mozilla_publice_license_v2,
    "mozilla public license version 2.0": mozilla_publice_license_v2,
    "mozilla": mozilla_publice_license,
    "mpeg-ssg" : mpeg_software_simulation,
    "mpi-permissive" : mpi_permissive_license,
    "mpich2" : mpich2_license,
    "mpl 2.0": mozilla_publice_license_v2,
    "mpl-1.0" : mozilla_public_license_1_0,
    "mpl-1.1" : mozilla_public_license_1_1,
    "mpl-2.0-no-copyleft-exception" : mozilla_public_license_2_0_no_copyleft_exception,
    "mpl-2.0": mozilla_publice_license_v2,
    "mpl": mozilla_publice_license,
    "mpl2": mozilla_publice_license_v2,
    "mplus" : mplus_font_license,
    "ms-lpl" : microsoft_limited_public_license,
    "ms-pl" : microsoft_public_license,
    "ms-rl" : microsoft_reciprocal_license,
    "mtll" : matrix_template_library_license,
    "mulanpsl-1.0" : mulan_permissive_software_license__version_1,
    "mulanpsl-2.0" : mulan_permissive_software_license__version_2,
    "multics" : multics_license,
    "mup" : mup_license,
    "naist-2003" : nara_institute_of_science_and_technology_license_2003,
    "nasa-1.3" : nasa_open_source_agreement_1_3,
    "naumen" : naumen_public_license,
    "nbpl-1.0" : net_boolean_public_license_v1,
    "ncbi-pd" : ncbi_public_domain_notice,
    "ncgl-uk-2.0" : non_commercial_government_licence,
    "ncl" : ncl_source_code_license,
    "ncsa" : university_of_illinois_ncsa_open_source_license,
    "net-snmp": net_snmp_license,
    "netcdf" : netcdf_license,
    "new bsd license": bsd_license_c3, # Source: https://opensource.org/license/BSD-3-Clause
    "new bsd": bsd_license_c3, # Source: https://opensource.org/license/BSD-3-Clause
    "newsletr" : newsletr_license,
    "ngpl" : nethack_general_public_license,
    "ngrep" : ngrep,
    "nicta-1.0" : nicta_public_software_license__version_1_0,
    "nist-pd-fallback" : nist_public_domain_notice_with_license_fallback,
    "nist-pd" : nist_public_domain_notice,
    "nist-software" : nist_software_license,
    "nlod-1.0" : norwegian_licence_for_open_government_data_nlod_1_0,
    "nlod-2.0" : norwegian_licence_for_open_government_data_nlod_2_0,
    "nlpl" : no_limit_public_license,
    "nokia" : nokia_open_source_license,
    "nosl" : netizen_open_source_license,
    "noweb" : noweb_license,
    "npl-1.0" : netscape_public_license_v1_0,
    "npl-1.1" : netscape_public_license_v1_1,
    "nposl-3.0" : non_profit_open_software_license_3_0,
    "nrl" : nrl_license,
    "ntia-pd" : ntia_pd,
    "ntp-0" : ntp_no_attribution,
    "ntp" : ntp_license,
    "nunit": nunit_license,
    "o-uda-1.0" : open_use_of_data_agreement_v1_0,
    "oar" : oar_license,
    "occt-pl" : open_cascade_technology_public_license,
    "oclc-2.0" : oclc_research_public_license_2_0,
    "odbl-1.0" : open_data_commons_open_database_license_v1_0,
    "odc-by-1.0" : open_data_commons_attribution_license_v1_0,
    "offis" : offis_license,
    "ofl-1.0-no-rfn" : sil_open_font_license_1_0_with_no_reserved_font_name,
    "ofl-1.0-rfn" : sil_open_font_license_1_0_with_reserved_font_name,
    "ofl-1.0" : sil_open_font_license_1_0,
    "ofl-1.1-no-rfn" : sil_open_font_license_1_1_with_no_reserved_font_name,
    "ofl-1.1-rfn" : sil_open_font_license_1_1_with_reserved_font_name,
    "ofl-1.1" : sil_open_font_license_1_1,
    "ogc-1.0" : ogc_software_license__version_1_0,
    "ogdl-taiwan-1.0" : taiwan_open_government_data_license__version_1_0,
    "ogl-canada-2.0" : open_government_licence___canada,
    "ogl-uk-1.0" : open_government_licence_v1_0,
    "ogl-uk-2.0" : open_government_licence_v2_0,
    "ogl-uk-3.0" : open_government_licence_v3_0,
    "ogtsl" : open_group_test_suite_license,
    "oldap-1.1" : open_ldap_public_license_v1_1,
    "oldap-1.2" : open_ldap_public_license_v1_2,
    "oldap-1.3" : open_ldap_public_license_v1_3,
    "oldap-1.4" : open_ldap_public_license_v1_4,
    "oldap-2.0.1" : open_ldap_public_license_v2_0_1,
    "oldap-2.0" : open_ldap_public_license_v2_0_or_possibly_2_0a_and_2_0b,
    "oldap-2.1" : open_ldap_public_license_v2_1,
    "oldap-2.2.1" : open_ldap_public_license_v2_2_1,
    "oldap-2.2.2" : open_ldap_public_license_2_2_2,
    "oldap-2.2" : open_ldap_public_license_v2_2,
    "oldap-2.3" : open_ldap_public_license_v2_3,
    "oldap-2.4" : open_ldap_public_license_v2_4,
    "oldap-2.5" : open_ldap_public_license_v2_5,
    "oldap-2.6" : open_ldap_public_license_v2_6,
    "oldap-2.7" : open_ldap_public_license_v2_7,
    "oldap-2.8" : open_ldap_public_license_v2_8,
    "olfl-1.3" : open_logistics_foundation_license_version_1_3,
    "oml" : open_market_license,
    "openpbs-2.3" : openpbs_v2_3_software_license,
    "openssl-standalone" : openssl_license___standalone,
    "openssl" : openssl_license,
    "openvision" : openvision_license,
    "opl-1.0" : open_public_license_v1_0,
    "opl-uk-3.0" : united_kingdom_open_parliament_licence_v3_0,
    "opubl-1.0" : open_publication_license_v1_0,
    "oset-pl-2.1" : oset_public_license_version_2_1,
    "osl-1.0" : open_software_license_1_0,
    "osl-1.1" : open_software_license_1_1,
    "osl-2.0" : open_software_license_2_0,
    "osl-2.1" : open_software_license_2_1,
    "osl-3.0" : open_software_license_3_0,
    "padl" : padl_license,
    "parity-6.0.0" : the_parity_public_license_6_0_0,
    "parity-7.0.0" : the_parity_public_license_7_0_0,
    "pddl-1.0" : open_data_commons_public_domain_dedication_and_license_1_0,
    "php-3.0" : php_license_v3_0,
    "php-3.01" : php_license_v3_01,
    "pixar" : pixar_license,
    "pkgconf" : pkgconf_license,
    "plexus" : plexus_classworlds_license,
    "pnmstitch" : pnmstitch_license,
    "polyform-noncommercial-1.0.0" : polyform_noncommercial_license_1_0_0,
    "polyform-small-business-1.0.0" : polyform_small_business_license_1_0_0,
    "postgresql" : postgresql_license,
    "ppl" : peer_production_license,
    "psf 1.0": python_license_v1,
    "psf 1": python_license_v1,
    "psf 2.0": python_license_v2,
    "psf 2": python_license_v2,
    "psf license 1.0": python_license_v1,
    "psf license 1": python_license_v1,
    "psf license 2.0": python_license_v2,
    "psf license 2": python_license_v2,
    "psf license v1.0": python_license_v1,
    "psf license v1": python_license_v1,
    "psf license v2.0": python_license_v2,
    "psf license v2": python_license_v2,
    "psf license": python_license,
    "psf v1.0": python_license_v1,
    "psf v1": python_license_v1,
    "psf v2.0": python_license_v2,
    "psf v2": python_license_v2,
    "psf-1.0": python_license_v1,
    "psf-1": python_license_v1,
    "psf-2.0": python_license_v2,
    "psf-2": python_license_v2,
    "psf": python_license,
    "psfl": python_license,
    "psfrag" : psfrag_license,
    "psutils" : psutils_license,
    "python 1.0": python_license_v1,
    "python 1": python_license_v1,
    "python 2.0": python_license_v2,
    "python 2": python_license_v2,
    "python software foundation license": python_license,
    "python style 1.0": python_license_v1,
    "python style 1": python_license_v1,
    "python style 2.0": python_license_v2,
    "python style 2": python_license_v2,
    "python style v1.0": python_license_v1,
    "python style v1": python_license_v1,
    "python style v2.0": python_license_v2,
    "python style v2": python_license_v2,
    "python style": python_license,
    "python v1.0": python_license_v1,
    "python v1": python_license_v1,
    "python v2.0": python_license_v2,
    "python v2": python_license_v2,
    "Python Software Foundation License 2.0": python_license_v2,
    "python-2.0.1" : python_license_2_0_1,
    "python-2.0" : python_license_2_0,
    "python-ldap" : python_ldap_license,
    "python": python_license,
    "qhull" : qhull_license,
    "qpl-1.0-inria-2004" : q_public_license_1_0___inria_2004_variant,
    "qpl-1.0" : q_public_license_1_0,
    "radvd" : radvd_license,
    "rdisc" : rdisc_license,
    "repoze public license": repoze_license,
    "revised bsd license": bsd_license_c3,
    "revised bsd": bsd_license_c3, 
    "rhecos-1.1" : red_hat_ecos_public_license_v1_1,
    "rpl-1.1" : reciprocal_public_license_1_1,
    "rpl-1.5" : reciprocal_public_license_1_5,
    "rpsl-1.0" : realnetworks_public_source_license_v1_0,
    "rsa-md" : rsa_message_digest_license,
    "rscpl" : ricoh_source_code_public_license,
    "ruby-pty" : ruby_pty_extension_license,
    "ruby" : ruby_license,
    "sax-pd-2.0" : sax_public_domain_notice_2_0,
    "sax-pd" : sax_public_domain_notice,
    "saxpath" : saxpath_license,
    "scea" : scea_shared_source_license,
    "schemereport" : scheme_language_report_license,
    "sendmail-8.23" : sendmail_license_8_23,
    "sendmail-open-source-1.1" : sendmail_open_source_license_v1_1,
    "sendmail" : sendmail_license,
    "sgi-b-1.0" : sgi_free_software_license_b_v1_0,
    "sgi-b-1.1" : sgi_free_software_license_b_v1_1,
    "sgi-b-2.0" : sgi_free_software_license_b_v2_0,
    "sgi-opengl" : sgi_opengl_license,
    "sgp4" : sgp4_permission_notice,
    "shl-0.5" : solderpad_hardware_license_v0_5,
    "shl-0.51" : solderpad_hardware_license__version_0_51,
    "simpl-2.0" : simple_public_license_2_0,
    "simplified bsd license" : bsd_2_clause_simplified_license, # Source: https://opensource.org/license/BSD-2-Clause
    "simplified bsd" : bsd_2_clause_simplified_license, # Source: https://opensource.org/license/BSD-2-Clause
    "sissl-1.2" : sun_industry_standards_source_license_v1_2,
    "sissl" : sun_industry_standards_source_license_v1_1,
    "sl" : sl_license,
    "sleepycat" : sleepycat_license,
    "smail-gpl" : smail_general_public_license,
    "smlnj" : standard_ml_of_new_jersey_license,
    "smppl" : secure_messaging_protocol_public_license,
    "snia" : snia_public_license_1_1,
    "snprintf" : snprintf_license,
    "sofa" : sofa,
    "softsurfer" : softsurfer_license,
    "soundex" : soundex_license,
    "spencer-86" : spencer_license_86,
    "spencer-94" : spencer_license_94,
    "spencer-99" : spencer_license_99,
    "spl-1.0" : sun_public_license_v1_0,
    "ssh-keyscan" : ssh_keyscan_license,
    "ssh-openssh" : ssh_openssh_license,
    "ssh-short" : ssh_short_notice,
    "ssleay-standalone" : ssleay_license___standalone,
    "sspl-1.0" : server_side_public_license__v_1,
    "standardml-nj" : standard_ml_of_new_jersey_license,
    "sugarcrm-1.1.3" : sugarcrm_public_license_v1_1_3,
    "sul-1.0" : sul_1_0,
    "sun-ppp-2000" : sun_ppp_license_2000,
    "sun-ppp" : sun_ppp_license,
    "sunpro" : sunpro_license,
    "swl" : scheme_widget_library_swl_software_license_agreement,
    "swrule" : swrule_license,
    "symlinks" : symlinks_license,
    "tapr-ohl-1.0" : tapr_open_hardware_license_v1_0,
    "tcl" : tcl_tk_license,
    "tcp-wrappers" : tcp_wrappers_license,
    "termreadkey" : termreadkey_license,
    "tgppl-1.0" : transitive_grace_period_public_licence_1_0,
    "the mit license (mit)": mit_license,
    "the mit license: http://www.opensource.org/licenses/mit-license.php": mit_license,
    "the mit license": mit_license,
    "the unlicense (unlicense)": unlicensed_license,
    "the unlicense": unlicensed_license,
    "thirdeye" : thirdeye_license,
    "threeparttable" : threeparttable_license,
    "tmate" : tmate_open_source_license,
    "torque-1.1" : torque_v2_5_software_license_v1_1,
    "tosl" : trusster_open_source_license,
    "tpdl" : time__parsedate_license,
    "tpl-1.0" : thor_public_license_1_0,
    "trustedqsl" : trustedqsl_license,
    "ttwl" : text_tabswrap_license,
    "ttyp0" : ttyp0_license,
    "tu-berlin-1.0" : technische_universitaet_berlin_license_1_0,
    "tu-berlin-2.0" : technische_universitaet_berlin_license_2_0,
    "ubuntu-font-1.0" : ubuntu_font_licence_v1_0,
    "ucar" : ucar_license,
    "ucl-1.0" : upstream_compatibility_license_v1_0,
    "ulem" : ulem_license,
    "umich-merit" : michigan_merit_networks_license,
    "unicode-3.0" : unicode_license_v3,
    "unicode-dfs-2015" : unicode_license_agreement___data_files_and_software_2015,
    "unicode-dfs-2016" : unicode_license_agreement___data_files_and_software_2016,
    "unicode-tou" : unicode_terms_of_use,
    "universal permissive license (upl)": universal_permissive_license,
    "unixcrypt" : unixcrypt_license,
    "unlicense-libtelnet" : unlicense_libtelnet,
    "unlicense-libwhirlpool" : unlicense_libwhirlpool,
    "unlicense": unlicensed_license,
    "unlicensed": unlicensed_license,
    "upl-1.0" : universal_permissive_license_v1_0,
    "upl": universal_permissive_license,
    "urt-rle" : utah_raster_toolkit_run_length_encoded_license,
    "vim" : vim_license,
    "vostrom" : vostrom_public_license_for_open_source,
    "vsl-1.0" : vovida_software_license_v1_0,
    "w3c-19980720" : w3c_software_notice_and_license_1998_07_20,
    "w3c-20150513" : w3c_software_notice_and_document_license_2015_05_13,
    "w3c" : w3c_software_notice_and_license_2002_12_31,
    "w3m" : w3m_license,
    "watcom-1.0" : sybase_open_watcom_public_license_1_0,
    "widget-workshop" : widget_workshop_license,
    "wsuipa" : wsuipa_license,
    "wtfpl": wtf_you_want_license,
    "wwl" : wwl_license,
    "wxwindows": wxwindows,
    "x11-distribute-modifications-variant" : x11_license_distribution_modification_variant,
    "x11-swapped" : x11_swapped_final_paragraphs,
    "x11" : x11_license,
    "xdebug-1.03" : xdebug_license_v_1_03,
    "xerox" : xerox_license,
    "xfig" : xfig_license,
    "xfree86-1.1" : xfree86_license_1_1,
    "xinetd" : xinetd_license,
    "xkeyboard-config-zinoviev" : xkeyboard_config_zinoviev_license,
    "xlock" : xlock_license,
    "xnet" : x_net_license,
    "xpp" : xpp_license,
    "xskat" : xskat_license,
    "xzoom" : xzoom_license,
    "ypl-1.0" : yahoo_public_license_v1_0,
    "ypl-1.1" : yahoo_public_license_v1_1,
    "zed" : zed_license,
    "zeeff" : zeeff_license,
    "zend-2.0" : zend_license_v2_0,
    "zimbra-1.3" : zimbra_public_license_v1_3,
    "zimbra-1.4" : zimbra_public_license_v1_4,
    "zlib-acknowledgement" : zlib_libpng_license_with_acknowledgement,
    "zlib" : zlib_license,
    "zpl 1": zope_public_license_v1,
    "zpl 2.1": zope_public_license_2_1,
    "zpl 2": zope_public_license_v2,
    "zpl-1.1" : zope_public_license_1_1,
    "zpl-2.0" : zope_public_license_2_0,
    "zpl-2.1" : zope_public_license_2_1,
    "zpl": zope_public_license,
}
